<?php if ( ! defined( 'ABSPATH' ) ) {
	die;
} // Cannot access pages directly.
// ===============================================================================================
// -----------------------------------------------------------------------------------------------
// FRAMEWORK SETTINGS
// -----------------------------------------------------------------------------------------------
// ===============================================================================================
$settings = array(
	'menu_title' => 'Theme Options',
	'menu_type'  => 'add_menu_page',
	'menu_slug'  => 'cs-framework',
	'ajax_save'  => false,
);

// ===============================================================================================
// -----------------------------------------------------------------------------------------------
// FRAMEWORK OPTIONS
// -----------------------------------------------------------------------------------------------
// ===============================================================================================
$options = array();

// ----------------------------------------
// general option section
// ----------------------------------------
$options[] = array(
	'name'   => 'general',
	'title'  => 'General',
	'icon'   => 'fa fa-globe',
	'fields' => array(
		array(
			'id'      => 'enable_lazy_load',
			'type'    => 'switcher',
			'title'   => 'Enable lazy load',
			'desc'    => 'Lazy Load delays loading of images in long web pages. Images outside of viewport will not be loaded before user scrolls to them. This option is available for Images and Maps',
			'default' => false
		),
		array(
			'id'    => 'reflector_enable_coming_soon',
			'type'  => 'switcher',
			'title' => 'Enable Coming Soon',
			'desc'  => 'Redirect on the select page when site loading',
		),
		array(
			'id'         => 'reflector_page_coming_soon',
			'type'       => 'select',
			'title'      => 'Page Coming Soon',
			'options'    => 'pages',
			'desc'       => 'Choose page',
			'query_args' => array(
				'sort_order'  => 'ASC',
				'sort_column' => 'post_title',
			),
			'dependency' => array( 'reflector_enable_coming_soon', '==', 'true' ),
		),
		array(
			'id'      => 'enable_copyright',
			'type'    => 'switcher',
			'title'   => 'Enable Copyright',
			'desc'    => 'Display a message when user click right button mouse on page',
			'default' => false,
		),
		array(
			'id'         => 'text_copyright',
			'type'       => 'wysiwyg',
			'title'      => 'Text Copyright',
			'default'    => '@' . date( 'Y' ),
			'dependency' => array( 'enable_copyright', '==', 'true' ),
			'desc'       => 'Enter your message for copyright'
		),
	) // end: fields
);


// ----------------------------------------
// Header option section
// ----------------------------------------
$options[] = array(
	'name'   => 'header',
	'title'  => 'Header',
	'icon'   => 'fa fa-star',
	'fields' => array(
		// Heading for each style
		array(
			'type'       => 'heading',
			'content'    => 'Header style - <i>Simple</i>',
			'dependency' => array( 'menu_style', '==', 'simple' )
		),
		array(
			'type'       => 'heading',
			'content'    => 'Header style - <i>Aside</i>',
			'dependency' => array( 'menu_style', '==', 'aside' )
		),
		array(
			'type'       => 'heading',
			'content'    => 'Header style - <i>Static aside</i>',
			'dependency' => array( 'menu_style', '==', 'static_aside' )
		),
		array(
			'type'       => 'heading',
			'content'    => 'Header style - <i>Bottom Menu</i>',
			'dependency' => array( 'menu_style', '==', 'bottom' )
		),
		array(
			'type'       => 'heading',
			'content'    => 'Header style - <i>Full Screen</i>',
			'dependency' => array( 'menu_style', '==', 'full_screen' )
		),
		array(
			'type'       => 'heading',
			'content'    => 'Header style - <i>Only logo</i>',
			'dependency' => array( 'menu_style', '==', 'only_logo' )
		),
		// Header style
		array(
			'id'         => 'menu_style',
			'type'       => 'image_select',
			'title'      => 'Header style:',
			'options'    => array(
				'simple'       => EF_URL . '/admin/assets/images/cs_images/menu_simple.jpg',
				'aside'        => EF_URL . '/admin/assets/images/cs_images/menu_aside.jpg',
				'static_aside' => EF_URL . '/admin/assets/images/cs_images/menu_static_aside.jpg',
				'bottom'       => EF_URL . '/admin/assets/images/cs_images/menu_bottom.jpg',
				'full_screen'  => EF_URL . '/admin/assets/images/cs_images/menu_full_screen.jpg',
				'only_logo'    => EF_URL . '/admin/assets/images/cs_images/menu_only_logo.jpg',
			),
			'radio'      => true,
			'attributes' => array(
				'data-depend-id' => 'menu_style',
			),
			'default'    => 'simple',
			'desc'       => 'Choose menu style'
		),
		// Option for style
		array(
			'type'       => 'heading',
			'content'    => 'Option for current style',
			'dependency' => array( 'menu_style', 'any', 'only_logo,static_aside,bottom,full_screen' )
		),
		array(
			'id'         => 'menu_copy',
			'type'       => 'textarea',
			'title'      => 'Copyright text',
			'settings'   => array(
				'textarea_rows' => 5,
				'media_buttons' => false,
			),
			'desc'       => 'Enter copyright text for Menu',
			'default'    => 'Reflector &copy; ' . date( 'Y' ) . '. Development with love by <a href="https://themeforest.net/user/fox-themes">FOXTHEMES</a>',
			'dependency' => array( 'menu_style', '==', 'static_aside' )
		),
		array(
			'id'         => 'bg_static_menu',
			'type'       => 'upload',
			'title'      => 'Background image for Static Menu',
			'default'    => '',
			'desc'       => 'Upload background image for menu section.',
			'dependency' => array( 'menu_style', '==', 'static_aside' ),
		),
		array(
			'id'         => 'social_title',
			'type'       => 'text',
			'title'      => 'Title for social',
			'default'    => 'GET IN TOUCH WITH US',
			'sanitize'   => 'textarea',
			'desc'       => 'Enter title for social',
			'dependency'   => array( 'menu_style', '==', 'full_screen' )
		),
		array(
			'id'           => 'header_social',
			'type'         => 'group',
			'title'        => 'Header social links',
			'desc'         => 'Add social links for header',
			'button_title' => 'Add New',
			'fields'       => array(
				array(
					'id'    => 'header_social_link',
					'type'  => 'text',
					'title' => 'Link'
				),
				array(
					'id'    => 'header_social_icon',
					'type'  => 'icon',
					'title' => 'Icon'
				)
			),
			'dependency'   => array( 'menu_style', 'any', 'bottom,full_screen' )
		),

    // Menu options
    array(
      'type'    => 'heading',
      'content' => 'Option for menu',
    ),
    array(
      'id'      => 'enable_click',
      'type'    => 'switcher',
      'title'   => 'Enable click on parent menu item',
      'desc'    => 'Makes a menu clickable for the parent item',
      'default' => false
    ),

		// Logo options
		array(
			'type'    => 'heading',
			'content' => 'Logo Options',
		),
		array(
			'id'      => 'site_logo',
			'type'    => 'radio',
			'title'   => 'Type of site logo',
			'options' => array(
				'txtlogo' => 'Text Logo',
				'imglogo' => 'Image Logo',
			),
			'default' => array( 'txtlogo' ),
			'desc'    => 'Choose type for logo'
		),
		array(
			'id'         => 'text_logo',
			'type'       => 'text',
			'title'      => 'Text Logo',
			'default'    => 'Reflector',
			'sanitize'   => 'textarea',
			'desc'       => 'Enter text for logo',
			'dependency' => array( 'site_logo_txtlogo', '==', 'true' ),
		),
		array(
			'id'         => 'text_logo_style',
			'type'       => 'radio',
			'title'      => 'Text logo style',
			'options'    => array(
				'default' => 'Default',
				'custom'  => 'Custom',
			),
			'default'    => array( 'default' ),
			'desc'       => 'Choose style for logo',
			'dependency' => array( 'site_logo_txtlogo', '==', 'true' )
		),
		array(
			'id'         => 'text_logo_width',
			'type'       => 'text',
			'title'      => 'Max width logo section',
			'default'    => '70px',
			'desc'       => 'Enter max width (in px)',
			'dependency' => array( 'text_logo_style_custom|site_logo_txtlogo', '==|==', 'true|true' )
		),
		array(
			'id'         => 'text_logo_color',
			'type'       => 'color_picker',
			'title'      => 'Text Logo Color',
			'default'    => '#fff',
			'desc'       => 'Choose color for logo',
			'dependency' => array( 'text_logo_style_custom|site_logo_txtlogo', '==|==', 'true|true' )
		),
		array(
			'id'         => 'text_logo_font_size',
			'type'       => 'text',
			'title'      => 'Text logo font size',
			'default'    => '20px',
			'desc'       => 'Enter font size (in px). By default the logo have 20px font size',
			'dependency' => array( 'text_logo_style_custom|site_logo_txtlogo', '==|==', 'true|true' )
		),
		array(
			'id'         => 'image_logo',
			'type'       => 'upload',
			'title'      => 'Site Logo',
			'default'    => get_template_directory_uri() . '/assets/images/logo.png',
			'desc'       => 'Upload any media using the WordPress Native Uploader.',
			'dependency' => array( 'site_logo_imglogo', '==', 'true' ),
		),
		array(
			'id'         => 'image_logo_scroll',
			'type'       => 'upload',
			'title'      => 'Site Logo on scroll',//
			'default'    => get_template_directory_uri() . '/assets/images/logo.png',
			'desc'       => 'Upload any media using the WordPress Native Uploader.',
			'dependency' => array( 'site_logo_imglogo', '==', 'true' ),
		),
		array(
			'id'         => 'image_logo_mobile',
			'type'       => 'upload',
			'title'      => 'Site Logo for mobile',
			'default'    => get_template_directory_uri() . '/assets/images/logo.png',
			'desc'       => 'Upload any media using the WordPress Native Uploader.',
			'dependency' => array( 'site_logo_imglogo', '==', 'true' ),
		),
		array(
			'id'         => 'img_logo_style',
			'type'       => 'radio',
			'title'      => 'Image logo style',
			'options'    => array(
				'default' => 'Default',
				'custom'  => 'Custom',
			),
			'default'    => array( 'default' ),
			'desc'       => 'Choose style for logo',
			'dependency' => array( 'site_logo_imglogo', '==', 'true' )
		),
		array(
			'id'         => 'img_logo_width',
			'type'       => 'text',
			'title'      => 'Site Logo Width Size*',
			'desc'       => 'Enter width size (in px). By default the logo have 60px width size',
			'dependency' => array( 'img_logo_style_custom|site_logo_imglogo', '==|==', 'true|true' )
		),
		array(
			'id'         => 'img_logo_height',
			'type'       => 'text',
			'title'      => 'Site Logo Height Size*',
			'desc'       => 'Enter height size (in px). By default the logo have 52px height size',
			'dependency' => array( 'img_logo_style_custom|site_logo_imglogo', '==|==', 'true|true' )
		),

	) // end: fields
);

// Typography
$options[] = array(
	'name'   => 'typography',
	'title'  => 'Typography',
	'icon'   => 'fa fa-font',
	'fields' => array(

		array(
			'type'    => 'heading',
			'content' => 'Typography Headings',
		),
		array(
			'id'              => 'heading',
			'type'            => 'group',
			'title'           => 'Typography Headings',
			'button_title'    => 'Add New',
			'accordion_title' => 'Add New',
			'desc'            => 'This option allows change headings style',

			// begin: fields
			'fields'          => array(

				// header size
				array(
					'id'      => 'heading_tag',
					'type'    => 'select',
					'title'   => 'Title Tag',
					'options' => array(
						'h1' => esc_html__( 'H1', 'reflector' ),
						'h2' => esc_html__( 'H2', 'reflector' ),
						'h3' => esc_html__( 'H3', 'reflector' ),
						'h4' => esc_html__( 'H4', 'reflector' ),
						'h5' => esc_html__( 'H5', 'reflector' ),
						'h6' => esc_html__( 'H6', 'reflector' ),
						'p'  => esc_html__( 'Paragraph', 'reflector' ),
					),
				),

				// font family
				array(
					'id'      => 'heading_family',
					'type'    => 'typography',
					'title'   => 'Font Family',
					'default' => array(
						'family'  => 'Open Sans',
						'variant' => 'regular',
						'font'    => 'google', // this is helper for output
					),
				),

				// font size
				array(
					'id'      => 'heading_size',
					'type'    => 'text',
					'title'   => 'Font Size (in px)',
					'default' => '54px',
				),
			),
		),

		array(
			'type'    => 'heading',
			'content' => 'Typography Menu',
		),
		// menu
		array(
			'id'      => 'menu_item_family',
			'type'    => 'typography',
			'title'   => 'Menu Item Font Family',
			'desc'    => 'This option allows change font family for menu item',
			'default' => array(
				'family'  => '',
				'variant' => 'regular',
				'font'    => 'websafe', // this is helper for output
			),
		),

		// font size
		array(
			'id'      => 'menu_item_size',
			'type'    => 'text',
			'title'   => 'Menu Item Font Size (in px)',
			'desc'    => 'This option allows change font size for menu item (in px)',
			'default' => '',
		),

		// line height
		array(
			'id'      => 'menu_line_height',
			'type'    => 'text',
			'title'   => 'Menu Line Height',
			'desc'    => 'This option allows change line height for menu item',
			'default' => '',
		),

		//submenu
		array(
			'id'      => 'submenu_item_family',
			'type'    => 'typography',
			'title'   => 'Submenu Item Font Family',
			'desc'    => 'This option allows change font family for submenu item',
			'default' => array(
				'family'  => '',
				'variant' => 'regular',
				'font'    => 'websafe', // this is helper for output
			),
		),

		// font size
		array(
			'id'      => 'submenu_item_size',
			'type'    => 'text',
			'title'   => 'Submenu Item Font Size (in px)',
			'desc'    => 'This option allows change font size for submenu item (in px)',
			'default' => '',
		),

		// line height
		array(
			'id'      => 'submenu_line_height',
			'type'    => 'text',
			'title'   => 'Submenu Line Height',
			'desc'    => 'This option allows change line height for submenu item',
			'default' => '',
		),
		array(
			'type'    => 'heading',
			'content' => 'Typography Button',
		),

		array(
			'id'      => 'all_button_font_family',
			'type'    => 'typography',
			'title'   => 'Button Font Family',
			'desc'    => 'This option allows change font family for button',
			'default' => array(
				'family'  => '',
				'variant' => 'regular',
				'font'    => 'websafe', // this is helper for output
			),
		),

		// font size
		array(
			'id'      => 'all_button_font_size',
			'type'    => 'text',
			'title'   => 'Button Font Size (in px)',
			'desc'    => 'This option allows change font size for button (in px)',
			'default' => '',
		),

		// line height
		array(
			'id'      => 'all_button_line_height',
			'type'    => 'text',
			'title'   => 'Button Line Height',
			'desc'    => 'This option allows change line height for button',
			'default' => '',
		),

		// font color
		array(
			'id'      => 'all_button_letter_spacing',
			'type'    => 'text',
			'title'   => 'Letter Spacing (in px)',
			'desc'    => 'This option allows change letter spacing for button (in px)',
			'default' => '',
		),
		array(
			'type'    => 'heading',
			'content' => 'Typography Links',
		),

		array(
			'id'      => 'all_links_font_family',
			'type'    => 'typography',
			'title'   => 'Button Font Family',
			'desc'    => 'This option allows change font family for link',
			'default' => array(
				'family'  => '',
				'variant' => 'regular',
				'font'    => 'websafe', // this is helper for output
			),
		),

		// font size
		array(
			'id'      => 'all_links_font_size',
			'type'    => 'text',
			'title'   => 'Links Font Size (in px)',
			'desc'    => 'This option allows change font size for link (in px)',
			'default' => '',
		),

		// line height
		array(
			'id'      => 'all_links_line_height',
			'type'    => 'text',
			'title'   => 'Links Line Height',
			'desc'    => 'This option allows change line height for link',
			'default' => '',
		),

		// font color
		array(
			'id'      => 'all_links_letter_spacing',
			'type'    => 'text',
			'title'   => 'Links Letter Spacing (in px)',
			'desc'    => 'This option allows change letter spacing for link (in px)',
			'default' => '',
		),
	),
);

// ----------------------------------------
// Custom color
// ----------------------------------------

$options[] = array(
	'name'   => 'theme_colors',
	'title'  => 'Theme Color',
	'icon'   => 'fa fa-magic',
	// begin: fields
	'fields' => array(
		array(
			'id'      => 'change_main_colors',
			'type'    => 'switcher',
			'title'   => 'Change Main Colors?',
			'default' => false,
			'desc'    => 'This option allows change main colors'
		),
		array(
			'id'         => 'primary_color',
			'type'       => 'color_picker',
			'title'      => 'Primary color',
			'default'    => '#b9a893',
			'dependency' => array('change_main_colors', '==', 'true')
		),
		array(
			'id'         => 'light_primary_color',
			'type'       => 'color_picker',
			'title'      => 'Light Primary color',
			'default'    => '#f8f6f5',
			'dependency' => array('change_main_colors', '==', 'true')
		),
		array(
			'id'         => 'light_color',
			'type'       => 'color_picker',
			'title'      => 'Light color',
			'default'    => '#fff',
			'dependency' => array('change_main_colors', '==', 'true')
		),
		array(
			'id'         => 'black_color',
			'type'       => 'color_picker',
			'title'      => 'Black color',
			'default'    => '#222',
			'dependency' => array('change_main_colors', '==', 'true')
		),
		array(
			'id'         => 'dark_color',
			'type'       => 'color_picker',
			'title'      => 'Dark color',
			'default'    => '#4c4c4c',
			'dependency' => array('change_main_colors', '==', 'true')
		),
		array(
			'id'         => 'grey_color',
			'type'       => 'color_picker',
			'title'      => 'Grey color',
			'default'    => '#888',
			'dependency' => array('change_main_colors', '==', 'true')
		),
		array(
			'id'         => 'light_grey_color',
			'type'       => 'color_picker',
			'title'      => 'Light Grey color',
			'default'    => '#aaa',
			'dependency' => array('change_main_colors', '==', 'true')
		),
	), // end: fields
);



// ----------------------------------------
// Socials API Configuration
// ----------------------------------------
$options[]      = array(
	'name'        => 'socials',
	'title'       => 'Social',
	'icon'        => 'fa fa-instagram',

	// begin: fields
	'fields'      => array(
		array(
			'id'      => 'insta_username',
			'type'    => 'text',
			'title'   => 'Instagram username',
			'default' => '',
			'desc' => 'Enter Instagram username'
		),
		array(
			'id'      => 'insta_count',
			'type'    => 'text',
			'title'   => 'Instagram count images',
			'default' => '',
			'desc' => 'Enter count images'
		),
		array(
			'id'      => 'access_token_instagram',
			'type'    => 'text',
			'title'   => 'Instagram access token',
			'default' => '',
			'desc' => 'Enter Instagram access token'
		),
		array(
			'id'      => 'access_user_id',
			'type'    => 'text',
			'title'   => 'Instagram user id',
			'default' => '',
			'desc' => 'Enter Instagram user id'
		),
	) // end: fields
);


// ----------------------------------------
// Blog option section
// ----------------------------------------
$options[] = array(
	'name'   => 'blog',
	'title'  => 'Blog',
	'icon'   => 'fab fa-blogger',
	'fields' => array(
		array(
			'id'      => 'blog_title',
			'type'    => 'text',
			'title'   => 'Blog title',
			'desc'    => 'Enter title for blog',
			'default' => 'Blog'
		),
		array(
			'id'         => 'bg_img_blog',
			'type'       => 'upload',
			'title'      => 'Background image for banner',
			'default'    => '',
			'desc'       => 'Upload any media using the WordPress Native Uploader.',
		),
		array(
			'id'      => 'sidebar',
			'type'    => 'checkbox',
			'title'   => 'Show sidebar on pages:',
			'options' => array(
				'post' => 'Post',
				'blog' => 'Blog'
			),
			'default' => array( 'post', 'blog' ),
			'desc'    => 'Display sidebar on select pages'
		),

		array(
			'id'      => 'reflector_post_tags',
			'type'    => 'switcher',
			'title'   => 'Tags in posts',
			'default' => true,
			'desc'    => 'Display tags in posts'
		),
		array(
			'id'      => 'reflector_post_cat',
			'type'    => 'switcher',
			'title'   => 'Categories in posts',
			'default' => true,
			'desc'    => 'Display categories in posts'
		),

	) // end: fields
);


// ----------------------------------------
// Portfolio option section
// ----------------------------------------
$options[] = array(
	'name'   => 'portfolio',
	'title'  => 'Portfolio',
	'icon'   => 'fas fa-file-alt',
	'fields' => array(
		array(
			'id'      => 'navigation_portfolio',
			'type'    => 'switcher',
			'title'   => 'Navigation in portfolio (for all portfolios)',
			'default' => false,
			'desc'    => 'Display navigation (for all portfolios)'
		),
		array(
			'id'      => 'portfolio_protect_title',
			'type'    => 'textarea',
			'title'   => 'Portfolio protected text',
			'default' => '',
			'desc'    => 'Enter text for portfolio protected page'
		),
		array(
			'id'      => 'portfolio_slug',
			'type'    => 'text',
			'title'   => 'Portfolio Url Slug',
			'default' => '',
			'desc'    => 'Please update <a href="' . home_url('wp-admin/options-permalink.php') . '">permalinks</a> after this. '
		),
		array(
			'id'      => 'portfolio_category_slug',
			'type'    => 'text',
			'title'   => 'Portfolio Url Category Slug',
			'default' => '',
			'desc'    => 'Please update <a href="' . home_url('wp-admin/options-permalink.php') . '">permalinks</a> after this. '
		),
	) // end: fields
);


// ----------------------------------------
// Price List option section
// ----------------------------------------
$options[] = array(
	'name'   => 'pricelist',
	'title'  => 'Price List',
	'icon'   => 'fa fa-file-pdf',
	'fields' => array(
		array(
			'id'         => 'pdf_title',
			'type'       => 'text',
			'title'      => 'Title for Price List in PDF',
			'default'    => '',
			'sanitize'   => 'textarea',
			'desc'       => 'Add your title for Price List in PDF',
		),
		array(
			'id'         => 'pdf_subtitle',
			'type'       => 'textarea',
			'title'      => 'Subtitle for Price List in PDF',
			'default'    => '',
			'sanitize'   => 'textarea',
			'desc'       => 'Add your subtitle for Price List in PDF',
		),
		array(
			'id'         => 'pdf_pricelist_title',
			'type'       => 'text',
			'title'      => 'Title for client info fields in PDF',
			'default'    => '',
			'sanitize'   => 'textarea',
			'desc'       => 'Add your title for client info fields in PDF',
		),
		array(
			'id'         => 'pdf_packages_title',
			'type'       => 'text',
			'title'      => 'Title for Packages of Price List in PDF',
			'default'    => '',
			'sanitize'   => 'textarea',
			'desc'       => 'Add your title for Packages of Price List in PDF',
		),
	) // end: fields
);


// ----------------------------------------
// Footer option section                  -
// ----------------------------------------
$options[] = array(
	'name'   => 'footer',
	'title'  => 'Footer',
	'icon'   => 'fa fa-copyright',
	'fields' => array(
		// Footer with margin bottom.
		array(
			'type'       => 'heading',
			'content'    => 'Footer style - <i>Modern</i>',
			'dependency' => array( 'reflector_footer_style', '==', 'modern' ),
		),
		array(
			'type'       => 'heading',
			'content'    => 'Footer style - <i>Simple</i>',
			'dependency' => array( 'reflector_footer_style', '==', 'simple' ),
		),
		array(
			'type'       => 'heading',
			'content'    => 'Footer style - <i>Creative</i>',
			'dependency' => array( 'reflector_footer_style', '==', 'creative' ),
		),
		array(
			'id'         => 'reflector_footer_style',
			'type'       => 'image_select',
			'title'      => 'Footer style:',
			'options'    => array(
				'simple'   => EF_URL . '/admin/assets/images/cs_images/footer-simple.jpg',
				'modern'   => EF_URL . '/admin/assets/images/cs_images/footer-modern.jpg',
				'creative' => EF_URL . '/admin/assets/images/cs_images/footer-creative.jpg',
			),
			'radio'      => true,
			'attributes' => array(
				'data-depend-id' => 'reflector_footer_style',
			),
			'default'    => 'modern',
			'desc'       => 'Choose style for Footer'
		),
		array(
			'type'    => 'heading',
			'content' => 'Option for current style',
		),
		array(
			'id'         => 'modern_title_address',
			'type'       => 'text',
			'title'      => 'Title for address',
			'default'    => 'STUDIO',
			'sanitize'   => 'textarea',
			'desc'       => 'Add your title for address in footer',
			'dependency' => array( 'reflector_footer_style', '==', 'modern' ),
		),
		array(
			'id'         => 'modern_address',
			'type'       => 'textarea',
			'title'      => 'Address',
			'default'    => '231 Main Street Chicago, IL',
			'sanitize'   => 'textarea',
			'desc'       => 'Add your address in footer',
			'dependency' => array( 'reflector_footer_style', '==', 'modern' ),
		),
		array(
			'id'         => 'modern_title_phone',
			'type'       => 'text',
			'title'      => 'Title for Phone',
			'default'    => 'PHONE',
			'sanitize'   => 'textarea',
			'desc'       => 'Add your title for phone in footer',
			'dependency' => array( 'reflector_footer_style', '==', 'modern' ),
		),
		array(
			'id'         => 'modern_phone',
			'type'       => 'text',
			'title'      => 'Phone',
			'default'    => '312.229.9000 - 1 555 55 55',
			'sanitize'   => 'textarea',
			'desc'       => 'Add your phone in footer',
			'dependency' => array( 'reflector_footer_style', '==', 'modern' ),
		),
		array(
			'id'         => 'modern_logo',
			'type'       => 'upload',
			'title'      => 'Footer logo',
			'default'    => 'https://reflector.foxthemes.me/wp-content/uploads/2019/02/logo.png',
			'desc'       => 'Select footer logo',
			'dependency' => array( 'reflector_footer_style', '==', 'modern' ),
		),
		array(
			'id'      => 'enable_light_footer',
			'type'    => 'switcher',
			'title'   => 'Enable Light Background Footer',
			'default' => false,
			'desc'    => 'Turning on Light Background Footer',
			'dependency' => array( 'reflector_footer_style', '==', 'modern' ),
		),
		array(
			'id'         => 'creative_title_insta',
			'type'       => 'text',
			'title'      => 'Title for Instagram',
			'default'    => '',
			'sanitize'   => 'textarea',
			'desc'       => 'Add your title for Instagram in footer',
			'dependency' => array( 'reflector_footer_style', '==', 'creative' ),
		),
		array(
			'id'         => 'creative_insta',
			'type'       => 'text',
			'title'      => 'Instagram Username',
			'default'    => '',
			'sanitize'   => 'textarea',
			'desc'       => 'Add your Instagram username in footer',
			'dependency' => array( 'reflector_footer_style', '==', 'creative' ),
		),
		array(
			'id'         => 'creative_title_info',
			'type'       => 'text',
			'title'      => 'Title for Info',
			'default'    => '',
			'sanitize'   => 'textarea',
			'desc'       => 'Add your title for info in footer',
			'dependency' => array( 'reflector_footer_style', '==', 'creative' ),
		),

		array(
			'id'         => 'creative_subtitle_info',
			'type'       => 'text',
			'title'      => 'Subtitle for info',
			'default'    => '',
			'sanitize'   => 'textarea',
			'desc'       => 'Add your subtitle for Info in footer',
			'dependency' => array( 'reflector_footer_style', '==', 'creative' ),
		),
		array(
			'id'         => 'creative_info',
			'type'       => 'textarea',
			'title'      => 'Text for Info',
			'default'    => '',
			'sanitize'   => 'textarea',
			'desc'       => 'Add your text for info in footer',
			'dependency' => array( 'reflector_footer_style', '==', 'creative' ),
		),
		array(
			'id'           => 'creative_socials',
			'type'         => 'group',
			'title'        => 'Socials for footer',
			'desc'         => 'Add social links for footer',
			'button_title' => 'Add New',
			'fields'       => array(
				array(
					'id'    => 'creative_socials_url',
					'type'  => 'text',
					'title' => 'Link'
				),
				array(
					'id'    => 'creative_socials_icon',
					'type'  => 'icon',
					'title' => 'Icon'
				)
			),
			'default'      => array(
				array(
					'creative_socials_url'  => 'https://www.facebook.com/',
					'creative_socials_icon' => 'fa fa-facebook'
				),
				array(
					'creative_socials_url'  => 'https://twitter.com/',
					'creative_socials_icon' => 'fa fa-twitter'
				),
			),
			'dependency'   => array( 'reflector_footer_style', '==', 'creative' ),
		),
		array(
			'id'         => 'creative_title_form',
			'type'       => 'text',
			'title'      => 'Title for form in footer',
			'default'    => '',
			'sanitize'   => 'textarea',
			'desc'       => 'Add your title for form in footer',
			'dependency' => array( 'reflector_footer_style', '==', 'creative' ),
		),
		array(
			'id'         => 'footer_form',
			'type'       => 'text',
			'title'      => 'Subscribe form ID',
			'default'    => '',
			'sanitize'   => 'textarea',
			'desc'       => 'Add your form id from shortcode Contact Form 7 Plugin.',
			'dependency' => array( 'reflector_footer_style', '==', 'creative' ),
		),
		array(
			'id'         => 'footer_text',
			'type'       => 'wysiwyg',
			'title'      => 'Copyright text',
			'settings'   => array(
				'textarea_rows' => 5,
				'media_buttons' => false,
			),
			'desc'       => 'Enter copyright text for footer',
			'default'    => 'Reflector &copy; ' . date( 'Y' ) . '. Development with love by <a href="https://themeforest.net/user/fox-themes">FOXTHEMES</a>',
			'dependency' => array( 'reflector_footer_style', 'any', 'simple,creative' )
		),
		array(
			'type'    => 'heading',
			'content' => 'Other Options',
		),
		array(
			'id'      => 'enable_parallax_footer',
			'type'    => 'switcher',
			'title'   => 'Enable Parallax Footer',
			'default' => false,
			'desc'    => 'Turning on Parallax footer',
		),

	) // end: fields
);

// ----------------------------------------
// 404 Page                               -
// ----------------------------------------
$options[] = array(
	'name'   => 'error_page',
	'title'  => '404 Page',
	'icon'   => 'fa fa-bolt',

	// begin: fields
	'fields' => array(
		array(
			'id'      => 'error_logo',
			'type'    => 'switcher',
			'title'   => 'Change logo for 404 page',
			'default' => false,
			'desc'    => 'This option allows change logo'
		),
		array(
			'id'         => 'error_site_logo',
			'type'       => 'radio',
			'title'      => 'Type of site logo',
			'options'    => array(
				'txtlogo' => 'Text Logo',
				'imglogo' => 'Image Logo',
			),
			'default'    => array('imglogo'),
			'desc'       => 'Choose type for logo',
			'dependency' => array('error_logo', '==', true),
		),
		array(
			'id'         => 'error_text_logo',
			'type'       => 'text',
			'title'      => 'Text Logo',
			'default'    => 'Reflector',
			'sanitize'   => 'textarea',
			'desc'       => 'Enter text for logo',
			'dependency' => array('error_site_logo_txtlogo|error_logo', '==|==', 'true|true'),
		),
		array(
			'id'         => 'error_image_logo',
			'type'       => 'upload',
			'title'      => 'Image Logo',
			'default'    => get_template_directory_uri() . '/assets/images/logo.png',
			'desc'       => 'Upload any media using the WordPress Native Uploader.',
			'dependency' => array('error_site_logo_imglogo|error_logo', '==|==', 'true|true'),
		),
		array(
			'id'      => 'error_title',
			'type'    => 'text',
			'title'   => 'Error Title',
			'desc'    => 'Enter title',
			'default' => 'Page not found',
		),
		array(
			'id'      => 'error_btn_text',
			'type'    => 'textarea',
			'title'   => 'Error button text',
			'default' => 'Go home',
			'desc'    => 'Enter button text'
		),
		array(
			'id'    => 'error_light',
			'type'  => 'switcher',
			'title' => 'Error light text',
		),
		array(
			'id'      => 'btn_style',
			'type'    => 'select',
			'title'   => 'Button Style',
			'options' => cs_buttons_theme_options(),
			'desc'    => 'Change button style'
		),
		array(
			'id'      => 'image_404',
			'type'    => 'upload',
			'title'   => '404 page background',
			'default' => '',
			'desc'    => 'Select background image'
		),
		array(
			'id'    => 'error_overlay',
			'type'  => 'switcher',
			'title' => 'Overlay for background',
		),
	) // end: fields
);
// ----------------------------------------
// Backup
// ----------------------------------------
$options[] = array(
	'name'   => 'backup_section',
	'title'  => 'Backup',
	'icon'   => 'fas fa-undo',

	// begin: fields
	'fields' => array(

		array(
			'type'    => 'notice',
			'class'   => 'warning',
			'content' => 'You can save your current options. Download a Backup and Import.',
		),

		array(
			'type' => 'backup',
		),

	)  // end: fields
);

CSFramework::instance( $settings, $options );
