<?php
/*
Plugin Name: Reflector Plugins
Version: 1.2.1
Description: Includes Portfolio Custom Post Type and Visual Composer Shortcodes
*/

// Define Constants
defined('EF_ROOT') or define('EF_ROOT', dirname(__FILE__));
defined('EF_URL') or define('EF_URL', plugins_url('reflector-plugins'));
defined('EF_VERSION') or define('EF_VERSION', '1.0');

if (!class_exists('Reflector_Plugins')) {

	require_once EF_ROOT . '/cs-framework/cs-framework.php';
	require_once EF_ROOT . '/lib/aq_resizer.php';
	// include functions
	require_once EF_ROOT . '/includes/functions_plugins.php';
	require_once EF_ROOT . '/register_post_types.php';
	require_once EF_ROOT . '/includes/lib/vendor/autoload.php';
	require_once EF_ROOT . '/lib/TwitterAPIExchange.php';


	require dirname(__FILE__) . '/plugin-update-checker/plugin-update-checker.php';
	$MyUpdateChecker = Puc_v4_Factory::buildUpdateChecker(
		'https://import.foxthemes.me/wp-update/?action=get_metadata&slug=reflector-plugins', //Metadata URL.
		__FILE__, //Full path to the main plugin file.
		'reflector-plugins' //Plugin slug. Usually it's the same as the name of the directory.
	);


	//	 add a skin in a plugin/theme
	if (!class_exists('The_Grid_Plugin')) {
		add_filter('tg_add_item_skin', function ($skins) {
			$dir            = __DIR__ . '/the-grid/';
			$directory_list = scandir($dir);

			$directory_list = array_slice($directory_list, 2);
			foreach ($directory_list as $directory) {

				$directory_templates_list = scandir($dir . $directory);
				$directory_templates_list = array_slice($directory_templates_list, 2);

				foreach ($directory_templates_list as $list) {

					$name = str_replace('-', ' ', $list);
					$name = substr($name, 3);

					// register a skin and add it to the main skins array
					$skins[$list] = array(
						'type' => $directory,
						'slug' => $list,
						'name' => $name,
						'php'  => EF_ROOT . '/the-grid/' . $directory . '/' . $list . '/' . $list . '.php',
						'css'  => EF_ROOT . '/the-grid/' . $directory . '/' . $list . '/' . $list . '.css',
						'col'  => 1, // col number in preview skin mode
						'row'  => 1  // row number in preview skin mode
					);
				}
			}

			// return the skins array + the new one you added (in this example 2 new skins was added)
			return $skins;
		});
	}
	/**
	 * Template editor init.
	 */
	if (!function_exists('reflector_include_vc_templates')) {
		function reflector_include_vc_templates()
		{
			if (class_exists('WPBakeryVisualComposerAbstract')) {
				require_once EF_ROOT . '/vc-templates/theme-vc-template-editor.php';
				require_once EF_ROOT . '/vc-templates/theme-vc-templates.php';

				$reflector_templates = new Reflector_Vc_Templates_Editor();

				return $reflector_templates->init();
			}
		}
	}

	add_action('init', 'reflector_include_vc_templates');


	// register scripts and styles for shortcodes
	add_action('wp_enqueue_scripts', 'reflector_register_scripts');
	function reflector_register_scripts()
	{

		// styles
		wp_register_style('tilt-css', EF_URL . '/shortcodes/assets/css/tilt.css', array('reflector_base_css'));
		wp_register_style('cs_about-css', EF_URL . '/shortcodes/assets/css/about.css', array('reflector_base_css'));
		wp_register_style('cs_slick-css', EF_URL . '/shortcodes/assets/css/slick.css', array('reflector_base_css'));
		wp_register_style('cs_banner-css', EF_URL . '/shortcodes/assets/css/banner.css', array('reflector_base_css'));
		wp_register_style('cs_banner_slider-css', EF_URL . '/shortcodes/assets/css/banner_slider.css', array('reflector_base_css'));
		wp_register_style('cs_headings-css', EF_URL . '/shortcodes/assets/css/headings.css', array('reflector_base_css'));
		wp_register_style('cs-service-item', EF_URL . '/shortcodes/assets/css/service-item.css', array('reflector_base_css'));
		wp_register_style('cs_portfolio_sliders-css', EF_URL . '/shortcodes/assets/css/portfolio_sliders.css', array('reflector_base_css'));
		wp_register_style('cs_testimonial-css', EF_URL . '/shortcodes/assets/css/testimonial.css', array('reflector_base_css'));
		wp_register_style('cs_line_of_images-css', EF_URL . '/shortcodes/assets/css/line_of_images.css', array('reflector_base_css'));
		wp_register_style('cs_contacts-css', EF_URL . '/shortcodes/assets/css/contacts.css', array('reflector_base_css'));
		wp_register_style('cs_team-css', EF_URL . '/shortcodes/assets/css/team.css', array('reflector_base_css'));
		wp_register_style('cs_instagram-css', EF_URL . '/shortcodes/assets/css/instagram.css', array('reflector_base_css'));
		wp_register_style('cs_post_slider-css', EF_URL . '/shortcodes/assets/css/post_slider.css', array('reflector_base_css'));
		wp_register_style('cs_info_block-css', EF_URL . '/shortcodes/assets/css/info_block.css', array('reflector_base_css'));
		wp_register_style('cs_twitter-css', EF_URL . '/shortcodes/assets/css/twitter.css', array('reflector_base_css'));
		wp_register_style('cs_pricing-css', EF_URL . '/shortcodes/assets/css/pricing.css', array('reflector_base_css'));
		wp_register_style('cs_coming_soon-css', EF_URL . '/shortcodes/assets/css/coming_soon.css', array('reflector_base_css'));
		wp_register_style('cs-justified-css', EF_URL . '/shortcodes/assets/css/justified-gallery.css', array('reflector_base_css'));
		wp_register_style('cs-portfolio-list-css', EF_URL . '/shortcodes/assets/css/portfolio-list.css', array('reflector_base_css'));
		wp_register_style('cs_custom_links-css', EF_URL . '/shortcodes/assets/css/custom-links.css', array('reflector_base_css'));
		wp_register_style('owlcarousel-css', EF_URL . '/shortcodes/assets/css/owlcarousel.css', array('reflector_base_css'));
		wp_register_style('cs-space-list-css', EF_URL . '/shortcodes/assets/css/space-list.css', array('reflector_base_css'));
		wp_register_style('cs_gallery-css', EF_URL . '/shortcodes/assets/css/cs_gallery.css', array('reflector_base_css'));
		wp_register_style('cs_cta-css', EF_URL . '/shortcodes/assets/css/cta.css', array('reflector_base_css'));
		wp_register_style('cs_post_list-css', EF_URL . '/shortcodes/assets/css/post_list.css', array('reflector_base_css'));
		wp_register_style('cs_pricelist-css', EF_URL . '/shortcodes/assets/css/pricelist.css', array('reflector_base_css'));
		wp_register_style('cs_faqs-css', EF_URL . '/shortcodes/assets/css/faqs.css', array('reflector_base_css'));
		wp_register_style('cs_video-css', EF_URL . '/shortcodes/assets/css/video.css', array('reflector_base_css'));

		// scripts
		wp_register_script('cs-about', EF_URL . '/shortcodes/assets/js/about.js', array('jquery'), '', true);
		wp_register_script('cs_banner_slider', EF_URL . '/shortcodes/assets/js/banner_slider.js', array('jquery'), false, true);
		wp_register_script('cs-typed', EF_URL . '/shortcodes/assets/js/typed.js', array('jquery'), false, true);
		wp_register_script('cs-gridrotator', EF_URL . '/shortcodes/assets/js/gridrotator.js', array('jquery'), false, true);
		wp_register_script('cs-banner', EF_URL . '/shortcodes/assets/js/banner.js', array('jquery'), false, true);
		wp_register_script('cs-instagram', EF_URL . '/shortcodes/assets/js/instagram.js', array('jquery'), '', true);
		wp_register_script('cs-info-block', EF_URL . '/shortcodes/assets/js/info_block.js', array('jquery'), '', true);
		wp_register_script('cs-coming-soon', EF_URL . '/shortcodes/assets/js/coming_soon.js', array('jquery'), '', true);
		wp_register_script('cs-justified', EF_URL . '/shortcodes/assets/js/lib/justified-gallery.js', array('jquery', 'imagesloaded'), '', true);
		wp_register_script('cs-equalHeights', EF_URL . '/shortcodes/assets/js/lib/equalHeights.js', array('jquery', 'imagesloaded'), '', true);
		wp_register_script('cs-three', EF_URL . '/shortcodes/assets/js/lib/three.js', array('jquery'), '', true);
		wp_register_script('cs-distortion', EF_URL . '/shortcodes/assets/js/lib/hover.js', array('jquery'), '', true);
		wp_register_script('cs-portfolio-list', EF_URL . '/shortcodes/assets/js/portfolio-list.js', array('jquery', 'imagesloaded'), '', true);
		wp_register_script('cs-animate', EF_URL . '/shortcodes/assets/js/animate.js', array('jquery', 'waypoints'), '', true);
		wp_register_script('tilt_effect', EF_URL . '/shortcodes/assets/js/lib/tilt.js', array('jquery'), '', true);
		wp_register_script('slider-transition', EF_URL . '/shortcodes/assets/js/lib/slider-transition.js', array('jquery', 'imagesloaded'), '', true);
		wp_register_script('flexslider', EF_URL . '/shortcodes/assets/js/flexslider.js', array('jquery'), '', true);
		wp_register_script('cs_kenburning', EF_URL . '/shortcodes/assets/js/kenburning.js', array('jquery'), '', true);
		wp_register_script('owlcarousel', EF_URL . '/shortcodes/assets/js/owlcarousel.js', array('jquery'), '', true);
		wp_register_script('cs-space-list', EF_URL . '/shortcodes/assets/js/space-list.js', array('jquery'), '', true);
		wp_register_script('cs_gallery', EF_URL . '/shortcodes/assets/js/cs_gallery.js', array('jquery'), '', true);
		wp_register_script('cs-tweenmax', EF_URL . '/shortcodes/assets/js/lib/tween-max.js', array('jquery', 'imagesloaded'), '', true);
		wp_register_script('cs-diagonal', EF_URL . '/shortcodes/assets/js/lib/diagonal.js', array('jquery', 'imagesloaded'), '', true);
		wp_register_script('cs-slick', EF_URL . '/shortcodes/assets/js/lib/slick.js', array('jquery', 'imagesloaded'), '', true);
		wp_register_script('cs_portfolio_sliders', EF_URL . '/shortcodes/assets/js/portfolio-sliders.js', array('jquery', 'cs-slick'), '', true);
		wp_register_script('cs_pricelist', EF_URL . '/shortcodes/assets/js/pricelist.js', array('jquery'), '', true);
	}

	new Reflector_Plugins;

	if (!function_exists('cs_buttons')) {
		function cs_buttons($exclude = '', $value_pref = 'a-btn-')
		{
			$url_btn = EF_URL . '/admin/assets/images/shortcodes_images/buttons/';
			$buttons = array(
				array(
					'value' => $value_pref . '1',
					'label' => esc_html__('Light Modern', 'js_composer'),
					'image' => $url_btn . 'a-btn-1.jpg'
				),
				array(
					'value' => $value_pref . '2',
					'label' => esc_html__('Dark Modern', 'js_composer'),
					'image' => $url_btn . 'a-btn-2.jpg'
				),
				array(
					'value' => $value_pref . '3',
					'label' => esc_html__('Dark button', 'js_composer'),
					'image' => $url_btn . 'a-btn-3.jpg'
				),
				array(
					'value' => $value_pref . '5',
					'label' => esc_html__('White transparent', 'js_composer'),
					'image' => $url_btn . 'a-btn-5.jpg'
				),
				array(
					'value' => $value_pref . '6',
					'label' => esc_html__('Dark transparent', 'js_composer'),
					'image' => $url_btn . 'a-btn-6.jpg'
				),
			);

			$return = array();

			foreach ($buttons as $button) {
				if ($button['value'] != $exclude) {
					$return[] = $button;
				}
			}

			return $return;
		}
	}

	if (!function_exists('cs_buttons_theme_options')) {
		function cs_buttons_theme_options()
		{
			$buttons = array(
				'a-btn-1' => 'Light Modern',
				'a-btn-3' => 'Dark Modern',
				'a-btn-4' => 'Dark button',
				'a-btn-5' => 'White transparent',
				'a-btn-6' => 'Dark transparent',
			);

			return $buttons;
		}
	}

	if (!function_exists('reflectoriframeDecoder')) {
		function reflectoriframeDecoder($iframe_code)
		{
			$iframe_code = base64_decode(strip_tags($iframe_code));
		}

		add_action('reflectoriframeDecoder', 'reflectoriframeDecoder');
	}

	/**
	 *
	 * Image Picker and Theme options styling.
	 * @since 1.0.0
	 * @version 1.0.0
	 *
	 **/

	if (!function_exists('reflector_enqueue_select')) {
		function reflector_enqueue_select()
		{
			wp_enqueue_style('reflector-admin-css', EF_URL . '/admin/assets/image-picker/admin.css');
			wp_enqueue_style('reflector-imagepicker-css', EF_URL . '/admin/assets/image-picker/image-picker.css');
			wp_enqueue_script('reflector-image-picker', EF_URL . '/admin/assets/image-picker/image-picker.min.js', array('jquery'), false, true);
		}
	}

	add_action('admin_enqueue_scripts', 'reflector_enqueue_select', 99);

	/**
	 *
	 * Get instagram images.
	 * @since 1.0.0
	 * @version 1.0.0
	 *
	 **/
	if (!function_exists('reflector_get_imstagram')) {
		function reflector_get_imstagram($username, $count_photos = 7)
		{

			if (empty($username)) {


				$response = wp_remote_get(sprintf('https://graph.instagram.com/me/media?fields=idmedia_type,media_url,permalink,caption,thumbnail_url,username&access_token=', cs_get_option('access_token_instagram'), $count_photos));
				if (is_wp_error($response) || 200 != wp_remote_retrieve_response_code($response)) {
					return false;
				}

				$data = json_decode(wp_remote_retrieve_body($response));

				$result = array();


				$username = '';

				foreach ($data->data as $key => $image) {
					$result[] = array(
						'link'      =>  $image->permalink,
						'image-url' =>  $image->media_url
					);
					if ($key == $count_photos - 1) {
						break;
					}
				}
				$result = array('items' => $result, 'username' => $username);

				return $result;
			} else {

				$instagram = get_transient('instagram-media-' . sanitize_title_with_dashes($username));
				$remote_wp = wp_remote_get("https://graph.instagram.com/me/media?fields=idmedia_type,media_url,permalink,caption,thumbnail_url,username&access_token=" . cs_get_option('access_token_instagram'), $count_photos);
				$instagram_response = json_decode($remote_wp['body']);

				$error = '';
				if (is_wp_error($remote_wp)) {
					$error = esc_html__('Unable to communicate with Instagram.', 'wiso');
				}

				if (200 != wp_remote_retrieve_response_code($remote_wp)) {
					$error = esc_html__('Instagram error.', 'wiso');
				}

				if (empty($error)) {
					$result = array();

					foreach ($instagram_response->data as $key => $image) {
						$result[] = array(
							'link'      =>  $image->permalink,
							'image-url' =>  $image->media_url
						);
						if ($key == $count_photos - 1) {
							break;
						}
					}

					$result = base64_encode(serialize($result));
					set_transient('instagram-media-' . sanitize_title_with_dashes($username), $result, apply_filters('null_instagram_cache_time', HOUR_IN_SECONDS * 2));
				}

				if ($error) {
					return $icontent = $error;
				} else {
					$result = unserialize(base64_decode($result));
					$result = array('items' => $result, 'username' => $username);

					return $result;
				}
			}
		}
	}
} // end of class_exists

if (!function_exists('reflector_animation')) {
	function reflector_animation($animation_figure, $animation_style)
	{
		$output = '';

		if (!empty($animation_figure)) {
			$animation_figure_hide = cs_get_option('animation_figure_hide-' . (int) preg_replace('/\D/', '', $animation_style));
			$animation_figure_hide = $animation_figure_hide ? 'hide-mobile' : '';
			$animation_figure_over = cs_get_option('animation_overflow-' . (int) preg_replace('/\D/', '', $animation_style));
			$animation_figure_over = $animation_figure_over ? 'overflow-visible' : '';

			foreach ($animation_figure as $figure) :
				$over            = !empty($figure['animation_figure_over']) ? 'over-content' : '';
				$output .= '<div class="cs-animation ' . esc_attr($animation_style . ' ' . $animation_figure_hide . ' ' . $animation_figure_over . ' ' . $over) . '">';
				$width            = !empty($figure['animation_width']) ? $figure['animation_width'] : '';
				$height           = !empty($figure['animation_height']) ? $figure['animation_height'] : '';
				$x                = !empty($figure['animation_x']) ? $figure['animation_x'] : 0;
				$y                = !empty($figure['animation_y']) ? $figure['animation_y'] : 0;
				$radius           = !empty($figure['animation_radius']) ? $figure['animation_radius'] : '';
				$bg_size          = !empty($figure['background_size']) ? $figure['background_size'] : '';
				$animation_move_x = !empty($figure['animation_move_x']) ? $figure['animation_move_x'] : 0;
				$animation_move_y = !empty($figure['animation_move_y']) ? $figure['animation_move_y'] : 0;
				$bg_image         = !empty($figure['animation_bg']['image']) ? $figure['animation_bg']['image'] : '';
				$bg_repeat        = !empty($figure['animation_bg']['repeat']) ? $figure['animation_bg']['repeat'] : '';
				$bg_position      = !empty($figure['animation_bg']['position']) ? $figure['animation_bg']['position'] : '';
				$bg_color         = !empty($figure['animation_bg']['color']) ? $figure['animation_bg']['color'] : '';
				$static_move      = !empty($figure['animation_static_move']) ? $figure['animation_static_move'] : '';
				$output           .= '<div class="cs-animation__figure js-animation-figure ' . esc_attr($static_move) . '" style="
												' . esc_attr(!empty($x) ? 'left: ' . $x . ';' : '') .
					esc_attr(!empty($width) ? 'width: ' . $width . ';' : '') .
					esc_attr(!empty($height) ? 'height: ' . $height . ';' : '') .
					esc_attr(!empty($y) ? 'top: ' . $y . ';' : '') . '
												" data-move-x="' . esc_attr($animation_move_x) . '" data-move-y="' . esc_attr($animation_move_y) . '">
										<div class="cs-animation__figure-inner" style="
												' . esc_attr(!empty($width) ? 'width: ' . $width . ';' : '') .
					esc_attr(!empty($height) ? 'height: ' . $height . ';' : '') .
					esc_attr(!empty($radius) ? 'border-radius: ' . $radius . ';' : '') .
					esc_attr(!empty($bg_image) ? 'background-image: url(' . $bg_image . ');' : '') .
					esc_attr(!empty($bg_size) ? 'background-size: ' . $bg_size . ';' : '') .
					esc_attr(!empty($bg_position) ? 'background-position: ' . $bg_position . ';' : '') .
					esc_attr(!empty($bg_color) ? 'background-color: ' . $bg_color . ';' : '') .
					esc_attr(!empty($bg_repeat) ? 'background-repeat: ' . $bg_repeat . ';' : '') . '
												"></div>
					 				</div>';
				$output .= '</div>';
			endforeach;
		}

		return $output;
	}
}

if (!function_exists('cs_css_animation')) {
	function cs_css_animation($param_name, $type, $heading, $dependency = true, $description = '')
	{
		$data = [];

		$data['cs_animation'] = array(
			''                      => __('None', 'js_composer'),
			'zoom-in-custom'        => __('Zoom in', 'js_composer'),
			'zoom-in-up-custom'     => __('Zoom in up', 'js_composer'),
			'zoom-in-down-custom'   => __('Zoom in down', 'js_composer'),
			'zoom-in-right-custom'  => __('Zoom in right', 'js_composer'),
			'zoom-in-left-custom'   => __('Zoom in left', 'js_composer'),
			'zoom-out-custom'       => __('Zoom out', 'js_composer'),
			'zoom-out-up-custom'    => __('Zoom out up', 'js_composer'),
			'zoom-out-down-custom'  => __('Zoom out down', 'js_composer'),
			'zoom-out-right-custom' => __('Zoom out right', 'js_composer'),
			'zoom-out-left-custom'  => __('Zoom out left', 'js_composer'),
			'fade-up'               => __('Fade up', 'js_composer'),
			'fade-down'             => __('Fade down', 'js_composer'),
			'fade-left'             => __('Fade left', 'js_composer'),
			'fade-right'            => __('Fade right', 'js_composer'),
		);

		$data['animation_style'] = array(
			'type'        => 'animation_style',
			'heading'     => __('CSS Animation for ' . $heading, 'js_composer'),
			'group'       => __('CSS Animation', 'js_composer'),
			'param_name'  => $param_name,
			'admin_label' => true,
			'value'       => '',
			'settings'    => array(
				'type'   => 'in',
				'custom' => array(
					array(
						'label'  => __('Default', 'js_composer'),
						'values' => array(
							__('Top to bottom', 'js_composer')           => 'top-to-bottom',
							__('Bottom to top', 'js_composer')           => 'bottom-to-top',
							__('Left to right', 'js_composer')           => 'left-to-right',
							__('Right to left', 'js_composer')           => 'right-to-left',
							__('Appear from center', 'js_composer')      => 'appear',
							__('Zoom in', 'js_composer')                 => 'zoom-in-custom',
							__('Zoom in up', 'js_composer')              => 'zoom-in-up-custom',
							__('Zoom in down', 'js_composer')            => 'zoom-in-down-custom',
							__('Zoom in right', 'js_composer')           => 'zoom-in-right-custom',
							__('Zoom in left', 'js_composer')            => 'zoom-in-left-custom',
							__('Zoom out', 'js_composer')                => 'zoom-out-custom',
							__('Zoom out up', 'js_composer')             => 'zoom-out-up-custom',
							__('Zoom out down', 'js_composer')           => 'zoom-out-down-custom',
							__('Zoom out right', 'js_composer')          => 'zoom-out-right-custom',
							__('Zoom out left', 'js_composer')           => 'zoom-out-left-custom',
							__('Scale from center', 'js_composer')       => 'scale-center',
							__('Scale from top right', 'js_composer')    => 'scale-top-right',
							__('Scale from top left', 'js_composer')     => 'scale-top-left',
							__('Scale from bottom right', 'js_composer') => 'scale-bottom-right',
							__('Scale from bottom left', 'js_composer')  => 'scale-bottom-left',
							__('Fade up', 'js_composer')                 => 'fade-up',
							__('Fade down', 'js_composer')               => 'fade-down',
							__('Fade left', 'js_composer')               => 'fade-left',
							__('Fade right', 'js_composer')              => 'fade-right',
							__('Left to right 3d', 'js_composer')        => 'left-to-right-3d',
							__('Right to left 3d', 'js_composer')        => 'right-to-left-3d',
							__('Bottom to top 3d', 'js_composer')        => 'bottom-to-top-3d',
							__('Top to bottom 3d', 'js_composer')        => 'top-to-bottom-3d',
						),
					),
				),
			),
			'description' => __('Select type of animation for element to be animated when it "enters" the browsers viewport. ' . $description, 'js_composer'),
			'dependency'  => $dependency,
		);

		$data['animation_duration'] = array(
			'type'             => 'textfield',
			'heading'          => __('CSS Animation Duration for ' . $heading, 'js_composer'),
			'group'            => __('CSS Animation', 'js_composer'),
			'param_name'       => $param_name,
			'edit_field_class' => 'vc_col-sm-6',
			'description'      => __('Enter animation duration on ms. ' . $description, 'js_composer'),
			'dependency'       => $dependency,
		);

		$data['animation_delay'] = array(
			'type'             => 'textfield',
			'heading'          => __('CSS Animation Delay for ' . $heading, 'js_composer'),
			'group'            => __('CSS Animation', 'js_composer'),
			'param_name'       => $param_name,
			'edit_field_class' => 'vc_col-sm-6',
			'description'      => __('Enter animation delay on ms. ' . $description, 'js_composer'),
			'dependency'       => $dependency,
		);

		return $data[$type];
	}
}

if (!function_exists('cs_css_animation_output')) {
	function cs_css_animation_output($animation_type, $animation_delay, $animation_duration)
	{
		$output = '';
		if ('' !== $animation_type && 'none' !== $animation_type) {
			wp_enqueue_script('waypoints');
			wp_enqueue_script('cs-animate');
			wp_enqueue_style('animate-css');
			$output = 'data-css-animation = ' . $animation_type;
			if ($animation_delay) {
				$output .= ' data-delay = ' . $animation_delay;
			}
			if ($animation_duration) {
				$output .= ' data-duration = ' . $animation_duration;
			}
		}

		return $output;
	}
}
