<?php

//REGISTER POST TYPES


class Reflector_Plugins {

	private $assets_js;

	public function __construct() {
		$this->assets_js  = plugins_url( '/includes/composer/js', __FILE__ );
		$this->assets_css = plugins_url( '/includes/composer/css', __FILE__ );


		add_action( 'init', array( $this, 'reflector_register_portfolio' ), 0 );
		add_action( 'admin_init', array( $this, 'reflector_load_map' ) );
		add_action( 'admin_print_scripts-post.php', array( $this, 'vc_enqueue_scripts' ), 99 );
		add_action( 'admin_print_scripts-post-new.php', array( $this, 'vc_enqueue_scripts' ), 99 );

		// add new params
		add_action( 'admin_init', array( $this, 'reflector_load_new_params' ) );

		add_action( 'admin_init', array( $this, 'reflector_load_shortcodes' ) );
		add_action( 'wp', array( $this, 'reflector_load_shortcodes' ) );

		add_action( 'admin_enqueue_scripts', array($this, 'reflector_wpc_date_style') );
		add_action( 'init', array( $this, 'reflector_vc_templates') );
		add_action( 'wp_ajax_reflector-send-email', array( $this, 'reflector_ajax_send_mail' ) );
		add_action( 'wp_ajax_nopriv_reflector-send-email', array( $this, 'reflector_ajax_send_mail' ) );
	}


	/**
	 * Template editor init.
	 */
	public function reflector_vc_templates() {
		if ( class_exists( 'Vc_Manager' ) && class_exists( 'WPBakeryShortCode' ) ) {
			$reflector_templates = new Reflector_Vc_Templates_Editor();
			return $reflector_templates->init();
		}
	}

	public function reflector_register_portfolio() {


		register_post_type( 'spaces',
			array(
				'labels' => array(
					'name' => esc_html__( 'Spaces','reflector-plugins'),
					'singular_name' => esc_html__( 'Item','reflector-plugins')
				),
				'supports'            => array( 'title', 'editor', 'thumbnail' ),
				'menu_icon' => 'dashicons-building',
				'public' => true,
				'has_archive' => true,
				'rewrite' => array('slug' => 'space'),
			)
		);

		// New Taxonomy
		register_taxonomy(
			'space-category',
			'spaces',
			array(
				'label' => esc_html__( 'Categories','reflector-plugins'),
				'rewrite' => array( 'slug' => 'space-category' ),
				'hierarchical' => true,
			)
		);



		$portfolio_url_slug = cs_get_option('portfolio_slug') ? cs_get_option('portfolio_slug') : 'portfolio-item';
		$portfolio_category_url_slug = cs_get_option('portfolio_category_slug') ? cs_get_option('portfolio_category_slug') : 'portfolio-category';

		$taxonomy_labels = array(
			'name'                       => 'Category',
			'singular_name'              => 'Category',
			'menu_name'                  => 'Categories',
			'all_items'                  => 'All Categories',
			'parent_item'                => 'Parent Category',
			'parent_item_colon'          => 'Parent Category:',
			'new_item_name'              => 'New Category Name',
			'add_new_item'               => 'Add New Category',
			'edit_item'                  => 'Edit Category',
			'update_item'                => 'Update Category',
			'separate_items_with_commas' => 'Separate categories with commas',
			'search_items'               => 'Search categories',
			'add_or_remove_items'        => 'Add or remove categories',
			'choose_from_most_used'      => 'Choose from the most used categories',
		);

		$taxonomy_rewrite = array(
			'slug'         => $portfolio_category_url_slug,
			'with_front'   => true,
			'hierarchical' => true,
		);

		$taxonomy_args = array(
			'labels'            => $taxonomy_labels,
			'hierarchical'      => true,
			'public'            => true,
			'show_ui'           => true,
			'show_admin_column' => true,
			'show_in_nav_menus' => true,
			'query_var'         => true,
			'show_tagcloud'     => true,
			'rewrite'           => $taxonomy_rewrite,
		);
		register_taxonomy( 'portfolio-category', array( 'portfolio' ), $taxonomy_args );



		$taxonomy_labels = array(
			'name'                       => 'Client',
			'singular_name'              => 'Client',
			'menu_name'                  => 'Clients',
			'all_items'                  => 'All Clients',
			'parent_item'                => 'Parent Client',
			'parent_item_colon'          => 'Parent Client:',
			'new_item_name'              => 'New Client Name',
			'add_new_item'               => 'Add New Client',
			'edit_item'                  => 'Edit Client Info',
			'update_item'                => 'Update Client',
			'separate_items_with_commas' => 'Separate clients with commas',
			'search_items'               => 'Search clients',
			'add_or_remove_items'        => 'Add or remove clients',
			'choose_from_most_used'      => 'Choose from the most used clients',
		);

		$taxonomy_rewrite = array(
			'slug'         => 'portfolio-client',
			'with_front'   => true,
			'hierarchical' => true,
		);

		$taxonomy_args = array(
			'labels'            => $taxonomy_labels,
			'hierarchical'      => true,
			'public'            => true,
			'show_ui'           => true,
			'show_admin_column' => true,
			'show_in_nav_menus' => true,
			'query_var'         => true,
			'show_tagcloud'     => true,
			'rewrite'           => $taxonomy_rewrite,
		);
		register_taxonomy( 'portfolio-client', array( 'portfolio' ), $taxonomy_args );


		$taxonomy_labels = array(
			'name'                       => 'Tag',
			'singular_name'              => 'Tag',
			'menu_name'                  => 'Tags',
			'all_items'                  => 'All Tags',
			'parent_item'                => 'Parent Tag',
			'parent_item_colon'          => 'Parent Tag:',
			'new_item_name'              => 'New Tag Name',
			'add_new_item'               => 'Add New Tag',
			'edit_item'                  => 'Edit Tag',
			'update_item'                => 'Update Tag',
			'separate_items_with_commas' => 'Separate categories with commas',
			'search_items'               => 'Search categories',
			'add_or_remove_items'        => 'Add or remove categories',
			'choose_from_most_used'      => 'Choose from the most used categories',
		);

		$taxonomy_rewrite = array(
			'slug'         => 'portfolio-tag',
			'with_front'   => true,
			'hierarchical' => true,
		);

		$taxonomy_args = array(
			'labels'            => $taxonomy_labels,
			'hierarchical'      => true,
			'public'            => true,
			'show_ui'           => true,
			'show_admin_column' => true,
			'show_in_nav_menus' => true,
			'query_var'         => true,
			'show_tagcloud'     => true,
			'rewrite'           => $taxonomy_rewrite,
		);
		register_taxonomy( 'portfolio-tag', array( 'portfolio' ), $taxonomy_args );


		//Register new post type
		$post_type_labels = array(
			'name'               => 'Portfolio',
			'singular_name'      => 'Portfolio',
			'menu_name'          => 'Portfolio',
			'parent_item_colon'  => 'Parent Portfolio:',
			'all_items'          => 'All Portfolios',
			'view_item'          => 'View Portfolio',
			'add_new_item'       => 'Add New Portfolio',
			'add_new'            => 'Add New',
			'edit_item'          => 'Edit Portfolio',
			'update_item'        => 'Update Portfolio',
			'search_items'       => 'Search portfolios',
			'not_found'          => 'No portfolios found',
			'not_found_in_trash' => 'No portfolios found in Trash',
		);

		$post_type_rewrite = array(
			'slug'       => $portfolio_url_slug,
			'with_front' => true,
		);

		$post_type_args = array(
			'label'              => 'portfolio',
			'description'        => 'Portfolio information pages',
			'labels'             => $post_type_labels,
			'supports'           => array( 'title', 'editor', 'excerpt', 'thumbnail', 'comments', 'revisions'),
			'taxonomies'         => array( 'post' ),
			'hierarchical'       => false,
			'public'             => true,
			'show_ui'            => true,
			'show_in_menu'       => true,
			'menu_icon'          => 'dashicons-format-gallery',
			'has_archive'        => true,
			'publicly_queryable' => true,
			'rewrite'            => $post_type_rewrite,
			'capability_type'    => 'post',
		);

		register_post_type( 'portfolio', $post_type_args );

	}

	public function reflector_load_map() {
		if ( class_exists( 'Vc_Manager' ) ) {
			require_once( EF_ROOT . '/' . 'includes/composer/map.php' );
			require_once( EF_ROOT . '/' . 'includes/composer/init.php' );
		}
	}

	public function reflector_load_shortcodes() {

		if ( class_exists( 'Vc_Manager' ) ) {

			if ( ! function_exists( 'reflector_wpc_date' ) ) {
				function reflector_wpc_date($settings, $value) {
					return '<div class="date-group">'
					       . '<input name="' . $settings['param_name'] . '" class="wpb_vc_param_value wpb-date ' . $settings['param_name'] . ' ' . $settings['type'] . '_field" type="text" value="' . $value . '"/>'
					       . '</div>';
				}
			}
			vc_add_shortcode_param('reflector_wpc_date', 'reflector_wpc_date', get_template_directory_uri() . '/assets/js/date.js');


			foreach ( glob( EF_ROOT . '/' . 'shortcodes/cs_*.php' ) as $shortcode ) {
				require_once( EF_ROOT . '/' . 'shortcodes/' . basename( $shortcode ) );
			}
			foreach ( glob( EF_ROOT . '/' . 'shortcodes/vc_*.php' ) as $shortcode ) {
				require_once( EF_ROOT . '/' . 'shortcodes/' . basename( $shortcode ) );
			}
		}

	}


	public function reflector_wpc_date_style() {
		wp_enqueue_script('jquery-ui-datepicker' );
	}

	public function reflector_load_new_params() {
		$params = glob( dirname( __FILE__ ) . '/params/*' , GLOB_ONLYDIR);
		foreach ( $params as $key => $name ) {
			require_once( __DIR__ . "/params/" . basename($name) . "/" . basename($name) . ".php" );
		}
	}

	public function vc_enqueue_scripts() {
		wp_enqueue_script( 'vc-script', $this->assets_js . '/vc-script.js', array( 'jquery' ), '1.0.0', true );
		wp_enqueue_style( 'rs-vc-custom', $this->assets_css . '/vc-style.css' );

		wp_enqueue_style( 'reflector-vc-style',   EF_URL . '/includes/assets/css/vc-style.css' );
		wp_enqueue_script( 'reflector-vc-script',   EF_URL . '/includes/assets/js/vc-script.js' ,      array('jquery'), '1.0.0', true );
        wp_enqueue_script( 'reflector-vc-image-picker',   EF_URL . '/includes/assets/js/vc-image-picker.js' ,      array('jquery'), '1.0.0', true );
	}


	public function reflector_ajax_send_mail() {

		parse_str( $_POST['form'], $params );

		$mail_to = isset($_POST['mail_to']) ? sanitize_email( $_POST['mail_to'] ) : '';
		$placeholder = isset($_POST['placeholder']) ? sanitize_text_field( $_POST['placeholder'] ) : '';
		$email = isset($params['reflector_email']) ? sanitize_email( $params['reflector_email'] ) : '';
		$name = isset($params['reflector_name']) ? sanitize_text_field( $params['reflector_name'] ) : '';
		$date = isset( $params['reflector_date']) ? sanitize_text_field( $params['reflector_date'] ) : '';
		$location = isset( $params['reflector_location']) ? sanitize_text_field( $params['reflector_location'] ) : '';
		$message_text = isset( $params['reflector_message']) ? sanitize_text_field( $params['reflector_message'] ) : '';
		$price = isset($_POST['price']) ? sanitize_text_field( $_POST['price'] ) : '';
		$subject = esc_html__('Message from ', 'reflector') . get_bloginfo();
		$res_pdf = '';
		if(isset($_POST['packages']) && !empty($_POST['packages'])){

			$packages = explode('&', $_POST['packages']);
			$res_pdf = $this->render_pdf( $params, $packages, $price, $placeholder );
		}


		$message = esc_html__('Name: ', 'reflector') . $name . "\r\n";
		$message .= esc_html__('Email: ', 'reflector') . $email . "\r\n";

		if(!empty($date)){
			$message .= esc_html__('Date: ', 'reflector') . $date . "\r\n";
		}
		if(!empty($location)){
			$message .= esc_html__('Location: ', 'reflector') . $location . "\r\n";
		}
		if(!empty($message_text)) {
			$message .= esc_html__( 'Message: ', 'reflector' ) . $message_text . "\r\n";
		}
		$message .= esc_html__('Total Price: ', 'reflector') . $price . "\r\n";
		$message .= esc_html__('Price list: ', 'reflector') . $res_pdf . "\r\n";

		$headers = 'Content-Type: text/html; charset=utf-8; \n\r From: '. get_bloginfo() .'\n\r';
		$send_message = wp_mail( $mail_to, $subject, $message, $headers );

		if ( $send_message ) {
			wp_send_json( $res_pdf );
		} else {
			wp_send_json( 'error' );
		}

	}

	public function render_pdf( $params = array(), $packages = array(), $price = '', $placeholder = '' ) {

		$upload_dir = wp_upload_dir();
		$time = time();
		$file = "{$upload_dir['path']}/price_list-{$time}.pdf";

		ob_start();
		require_once EF_ROOT . '/pdf-template/pricelist-pdf.php';
		$pdfHtml = ob_get_clean();

		$domPdf = new \Dompdf\Dompdf( array(
			'isRemoteEnabled' => true,
			'isHtml5ParserEnabled' => true,
		) );
		$domPdf->loadHtml( $pdfHtml );
		$domPdf->render();
		if ( file_put_contents( $file, $domPdf->output() ) ) {
			$file_url = "{$upload_dir['url']}/price_list-{$time}.pdf";
			return $file_url;
		}
		return false;

	}




} // end of class

