<?php
if ( function_exists( 'vc_map' ) ) {
	$url = EF_URL . '/admin/assets/images/shortcodes_images/headings/';
	vc_map(
		array(
			'name'        => __( 'Headings', 'js_composer' ),
			'base'        => 'cs_headings',
			'description' => __( 'Section with text button (with paddings)', 'js_composer' ),
			'category'    => __( 'Content', 'js_composer' ),
			'params'      => array(
				array(
					'type'        => 'select_preview',
					'param_name'  => 'style',
					'heading'     => esc_html__( 'Style', 'js_composer' ),
					'value'       => array(
						array(
							'label' => esc_html__( 'Modern', 'js_composer' ),
							'value' => 'modern',
							'image' => $url . 'modern.jpg'
						),
                        array(
							'label' => esc_html__( 'Modern with link', 'js_composer' ),
							'value' => 'modern_with_link',
							'image' => $url . 'modern.jpg'
						),
						array(
							'label' => esc_html__( 'Simple', 'js_composer' ),
							'value' => 'simple',
							'image' => $url . 'simple.jpg'
						),
						array(
							'label' => esc_html__( 'Classic', 'js_composer' ),
							'value' => 'classic',
							'image' => $url . 'classic.jpg'
						),
						array(
							'label' => esc_html__( 'Creative', 'js_composer' ),
							'value' => 'creative',
							'image' => $url . 'creative.jpg'
						),
						array(
							'label' => esc_html__( 'Urban', 'js_composer' ),
							'value' => 'urban',
							'image' => $url . 'urban.jpg'
						),
					),
					'admin_label' => true,
					'save_always' => true,
				),
				array(
					'type'       => 'checkbox',
					'heading'    => esc_html__( 'Enable light style?', 'js_composer' ),
					'param_name' => 'light_style',
					'std'        => '',
					'dependency' => array( 'element' => 'style', 'value' => array( 'classic' ) )
				),
				array(
					'type'        => 'attach_image',
					'heading'     => 'Image',
					'param_name'  => 'image',
					'admin_label' => true,
					'description' => 'Upload your image.',
					'dependency'  => array( 'element' => 'style', 'value' => array( 'creative' ) ),
				),
				array(
					'type'        => 'textarea',
					'heading'     => __( 'Subtitle', 'js_composer' ),
					'param_name'  => 'subtitle',
					'value'       => '',
					'description' => 'If you want mark in main color some words you can wrap them in tag &#60;i&#62;&#60;/i&#62;. Example: &#60;i&#62;Hello World&#60;/i&#62;',
					'dependency'  => array( 'element' => 'style', 'value' => array( 'classic', 'urban' ) )
				),
				array(
					'type'       => 'textarea',
					'heading'    => __( 'Title', 'js_composer' ),
					'param_name' => 'title',
					'value'      => '',
					'dependency'  => array( 'element' => 'style', 'value_not_equal_to' => array( 'modern_with_link' ) ),
				),
				array(
					'type'       => 'textarea',
					'heading'    => __( 'Description', 'js_composer' ),
					'param_name' => 'description',
					'value'      => '',
					'dependency' => array( 'element' => 'style', 'value' => array( 'simple', 'creative', 'urban' ) )
				),
				array(
					'type'        => 'vc_link',
					'heading'     => __( 'Button', 'js_composer' ),
					'description' => __( 'Please add link & name for your button', 'js_composer' ),
					'param_name'  => 'button',
					'dependency'  => array( 'element' => 'style', 'value' => array( 'simple', 'creative' ) )
				),
                array(
					'type'        => 'vc_link',
					'heading'     => __( 'Title & link', 'js_composer' ),
					'description' => __( 'Please add link & title', 'js_composer' ),
					'param_name'  => 'title_link',
					'dependency'  => array( 'element' => 'style', 'value' => array( 'modern_with_link' ) ),
				),
				array(
					'type'        => 'select_preview',
					'heading'     => __( 'Button style', 'js_composer' ),
					'description' => __( 'Please select style of your button', 'js_composer' ),
					'param_name'  => 'btn_style',
					'value'       => cs_buttons(),
					'dependency'  => array( 'element' => 'style', 'value' => array( 'simple', 'creative' ) )
				),
				array(
					'type'       => 'dropdown',
					'heading'    => esc_html__( 'Text align', 'js_composer' ),
					'param_name' => 'text_align',
					'value'      => array(
						'Text left'   => 'text-left',
						'Text center' => 'text-center',
						'Text right'  => 'text-right',
					),
					'dependency' => array( 'element' => 'style', 'value' => array( 'simple' ) ),
				),
			),

			//end params
		)
	);
}
if ( class_exists( 'WPBakeryShortCode' ) ) {
	/* Frontend Output Shortcode */

	class WPBakeryShortCode_cs_headings extends WPBakeryShortCode {
		protected function content( $atts, $content = null ) {
			/* get all params */
			extract( shortcode_atts( array(
				'title'       => '',
				'subtitle'    => '',
				'type'        => 'only_text',
				'description' => '',
				'button'      => '',
				'image'       => '',
				'light_style' => '',
				'title_link' => '',
				'btn_style'   => 'a-btn-1',
				'text_align'  => 'text-left',
				'style'       => 'modern',

			), $atts ) );

			$style = ! empty( $style ) ? $style : 'simple';

			// include needed stylesheets
			if ( ! in_array( "cs_headings-css", self::$css_scripts ) ) {
				self::$css_scripts[] = "cs_headings-css";
			}
			$this->enqueueCss();

			$light_style = isset( $light_style ) && ! empty( $light_style ) ? 'light_style' : '';
			$btn_style   = isset( $btn_style ) && ! empty( $btn_style ) ? $btn_style : 'a-btn-1';

			$class[] = $style;
			$class[] = $style == 'simple' && isset( $text_align ) && ! empty( $text_align ) ? $text_align : 'text-left';

			// start output
			ob_start(); ?>

            <div class="headings <?php echo esc_attr( implode( ' ', $class ) ); ?>">

				<?php
				//SIMPLE
				if ( $style == 'simple' ) {
					if ( ! empty( $title ) ) { ?>
                        <h3 class="title"><?php echo wp_kses_post( $title ); ?></h3>
					<?php }
					if ( ! empty( $description ) ) { ?>
                        <div class="text"><?php echo wp_kses_post( $description ); ?></div>
					<?php }

					if ( ! empty( $button ) ) {
						$url = vc_build_link( $button );
					}

					if ( ! empty( $url['url'] ) ) {
						$target = ! empty( $url['target'] ) ? $url['target'] : '_self'; ?>
                        <div class="button">
                            <a href="<?php echo esc_attr( $url['url'] ); ?>"
                               class="<?php echo esc_attr( $btn_style ); ?>"
                               target="<?php echo esc_attr( $target ); ?>">
								<?php echo esc_html( $url['title'] ); ?>
                            </a>
                        </div>
					<?php }
				} //CLASSIC

				if ( $style == 'modern' ) {
					if ( ! empty( $title ) ) { ?>
                        <h3 class="title"><?php echo wp_kses_post( $title ); ?></h3>
					<?php }
				}

				if( $style == 'modern_with_link' ){
					if ( ! empty( $title_link ) ) {
						$title_link = vc_build_link( $title_link );

						if ( ! empty( $title_link['url'] ) ) {
							$target = ! empty( $title_link['target'] ) ? $title_link['target'] : '_self'; ?>
                            <a href="<?php echo esc_url($title_link['url'] ); ?>" class="title" target="<?php echo esc_attr( $target); ?>">
                                <?php echo wp_kses_post( $title_link['title']); ?>
                            </a>
                        <?php }else{ ?>
                            <h3 class="title"><?php echo wp_kses_post( $title_link['title'] ); ?></h3>
                        <?php } ?>
					<?php }
                }

				if ( $style == 'classic' ) {
					if ( ! empty( $subtitle ) ) { ?>
                        <div class="subtitle <?php echo esc_attr( $light_style ); ?>"><?php echo wp_kses_post( $subtitle ); ?></div>
					<?php }
					if ( ! empty( $title ) ) { ?>
                        <h3 class="title <?php echo esc_attr( $light_style ); ?>"><?php echo wp_kses_post( $title ); ?></h3>
					<?php }
				}

				if ( $style == 'creative' ) {

					$image_url = ( ! empty( $image ) && is_numeric( $image ) ) ? wp_get_attachment_url( $image ) : '';
					$image_alt = get_post_meta( $image, '_wp_attachment_image_alt', true );

					if ( ! empty( $image ) ) { ?>
                        <div class="image-wrap">
                            <img src="<?php echo esc_url( $image_url ); ?>" alt="<?php echo esc_attr( $image_alt ); ?>">
                        </div>
					<?php }

					if ( ! empty( $title ) ) { ?>
                        <h3 class="title"><?php echo wp_kses_post( $title ); ?></h3>
					<?php }
					if ( ! empty( $description ) ) { ?>
                        <div class="text"><?php echo wp_kses_post( $description ); ?></div>
					<?php }

					if ( ! empty( $button ) ) {
						$url = vc_build_link( $button );
					}

					if ( ! empty( $url['url'] ) ) {
						$target = ! empty( $url['target'] ) ? $url['target'] : '_self'; ?>
                        <div class="button">
                            <a href="<?php echo esc_attr( $url['url'] ); ?>"
                               class="<?php echo esc_attr( $btn_style ); ?>"
                               target="<?php echo esc_attr( $target ); ?>">
								<?php echo esc_html( $url['title'] ); ?>
                            </a>
                        </div>
					<?php }
				}

				if ( $style == 'urban' ) {

					if ( ! empty( $subtitle ) ) { ?>
                        <div class="subtitle"><?php echo wp_kses_post( $subtitle ); ?></div>
					<?php }

					if ( ! empty( $title ) ) { ?>
                        <h3 class="title"><?php echo wp_kses_post( $title ); ?></h3>
					<?php }

					if ( ! empty( $description ) ) { ?>
                        <div class="text"><?php echo wp_kses_post( $description ); ?></div>
					<?php }

				} ?>

            </div>

			<?php // end output

			return ob_get_clean();
		}
	}
}