<?php
if ( function_exists( 'vc_map' ) ) {
	$url = EF_URL . '/admin/assets/images/shortcodes_images/post_list/';
	vc_map(
		array(
			'name'     => __( 'Post list', 'js_composer' ),
			'base'     => 'cs_post_list',
			'category' => __( 'Content', 'js_composer' ),
			'params'   => array(
				array(
					'type'       => 'select_preview',
					'heading'    => __( 'Style', 'js_composer' ),
					'param_name' => 'style',
					'value'      => array(
						array(
							'value' => 'list_center',
							'label' => esc_html__( 'List center', 'js_composer' ),
							'image' => $url . 'list_center.jpg'
						),
						array(
							'value' => 'simple_categories',
							'label' => esc_html__( 'Simple Categories', 'js_composer' ),
							'image' => $url . 'simple_categories.jpg'
						),
					),
				),
				array(
					'type'       => 'textfield',
					'heading'    => __( 'Title', 'js_composer' ),
					'param_name' => 'title',
					'dependency'  => array( 'element' => 'style', 'value' => array( 'simple_categories' ) )
				),
				array(
					'type'        => 'dropdown',
					'heading'     => 'Image original size',
					'description' => __( 'Please select image size', 'js_composer' ),
					'param_name'  => 'image_original_size',
					'value'       => array_merge( array( 'full' ), get_intermediate_image_sizes() ),
					'dependency'  => array( 'element' => 'style', 'value' => array( 'list_center' ) )
				),
				array(
					'type'        => 'vc_efa_chosen',
					'heading'     => __( 'Select Categories', 'js_composer' ),
					'param_name'  => 'cats',
					'description' => __( 'Please select categories', 'js_composer' ),
					'placeholder' => __( 'Select category', 'js_composer' ),
					'value'       => reflector_element_values( 'category', array(
						'sort_order' => 'ASC',
						'taxonomy'   => 'category',
						'hide_empty' => false,
					) ),
					'std'         => '',
				),
				array(
					'type'        => 'dropdown',
					'heading'     => __( 'Order by', 'js_composer' ),
					'param_name'  => 'orderby',
					'value'       => array(
						'',
						__( 'Date', 'js_composer' )          => 'date',
						__( 'ID', 'js_composer' )            => 'ID',
						__( 'Author', 'js_composer' )        => 'author',
						__( 'Title', 'js_composer' )         => 'title',
						__( 'Modified', 'js_composer' )      => 'modified',
						__( 'Random', 'js_composer' )        => 'rand',
						__( 'Comment count', 'js_composer' ) => 'comment_count'
					),
					'dependency'  => array( 'element' => 'style', 'value' => array( 'list_center' ) ),
					'description' => sprintf( __( 'Select how to sort retrieved posts. More at %s.', 'js_composer' ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' )
				),
				array(
					'type'        => 'dropdown',
					'heading'     => __( 'Sort order', 'js_composer' ),
					'param_name'  => 'order',
					'value'       => array(
						__( 'Descending', 'js_composer' ) => 'DESC',
						__( 'Ascending', 'js_composer' )  => 'ASC',
					),
					'dependency'  => array( 'element' => 'style', 'value' => array( 'list_center' ) ),
					'description' => sprintf( __( 'Select ascending or descending order. More at %s.', 'js_composer' ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' )
				),
				array(
					'type'        => 'textfield',
					'heading'     => __( 'Count items', 'js_composer' ),
					'description' => __( 'Please specify how many elements of the portfolio will appear on the page', 'js_composer' ),
					'param_name'  => 'count',
					'dependency'  => array( 'element' => 'style', 'value' => array( 'list_center' ) ),
				),
				array(
					'type'        => 'vc_link',
					'heading'     => __( 'Button', 'js_composer' ),
					'description' => __( 'Please add link & name for your button', 'js_composer' ),
					'param_name'  => 'button',
					'dependency'  => array( 'element' => 'style', 'value' => array( 'simple_categories' ) )
				),
				array(
					'type'        => 'select_preview',
					'heading'     => __( 'Button style', 'js_composer' ),
					'description' => __( 'Please select style of your button', 'js_composer' ),
					'param_name'  => 'btn_style',
					'value'       => cs_buttons(),
					'dependency'  => array( 'element' => 'style', 'value' => array( 'simple_categories' ) )
				),
			),

			//end params
		)
	);
}

if ( class_exists( 'WPBakeryShortCode' ) ) {
	/* Frontend Output Shortcode */

	class WPBakeryShortCode_cs_post_list extends WPBakeryShortCode {
		protected function content( $atts, $content = null ) {
			/* get all params */
			extract( shortcode_atts( array(
				'cats'                => '',
				'image_original_size' => 'full',
				'style'               => 'list_center',
				'count'               => '',
				'orderby'             => '',
				'order'               => 'date',
				'button'              => '',
				'title'              => '',
				'btn_style'           => 'a-btn-1',

			), $atts ) );


			// include needed stylesheets
			if ( ! in_array( "cs_post_list-css", self::$css_scripts ) ) {
				self::$css_scripts[] = "cs_post_list-css";
			}
			$this->enqueueCss();


			// base args
			$args = array(
				'post_type'      => 'post',
				'posts_per_page' => ( ! empty( $count ) && is_numeric( $count ) ) ? $count : 9,
				'paged'          => ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1
			);

			// Order posts
			if ( null !== $orderby ) {
				$args['orderby'] = $orderby;
			}
			$args['order'] = $order;

			// category
			if ( ! empty( $cats ) ) {

				$term_array = explode( ',', $cats );
				$cats       = array();

				foreach ( $term_array as $term_slug ) {
					$term_info = get_term_by( 'slug', $term_slug, 'category' );
					$cats[]    = $term_info->term_id;
				}

				$cats              = implode( ',', $cats );
				$args['tax_query'] = array(
					array(
						'taxonomy' => 'category',
						'field'    => 'term_id',
						'terms'    => explode( ',', $cats ),
					)
				);
			}

			$posts = new WP_Query( $args );

			ob_start(); ?>

			<?php if ( $posts->have_posts() ) { ?>
                <div class="post-list-wrapper <?php echo esc_attr( $style ); ?>">
					<?php if ( $style == 'list_center' ) {

						while ( $posts->have_posts() ) :
							$posts->the_post();
							$image_id = get_post_thumbnail_id( $posts->ID );
							$link     = get_the_permalink();

							if ( ! empty( $image_id ) ) {
								$no_image = '';
							} else {
								$no_image = ' no-image';
							} ?>


                            <div <?php post_class( 'post col-xs-12 post-content center-style format-post-image' . $no_image ); ?>>
                                <div class="post-wrap-item">

									<?php if ( ! empty( $image_id ) ) {
										$image     = wp_get_attachment_image_url( $image_id, 'full' );
										$image_alt = get_post_meta( $image_id, '_wp_attachment_image_alt', true ); ?>
                                        <div class="post-media">
											<?php echo reflector_the_lazy_load_flter( $image, array(
												'class' => 's-img-switch',
												'alt'   => $image_alt
											) ); ?>
                                        </div>
									<?php } ?>
                                    <div class="info-wrap">
                                        <div class="left-wrap">
                                            <div class="flex-wrap">
                                                <span class="category"><?php the_category( ', ' ); ?></span>
                                                <span class="date">
                                                    <?php the_time( get_option( 'date_format' ) ); ?>
                                                </span>
                                            </div>

                                            <h4 class="title"><a
                                                        href="<?php echo esc_url( $link ); ?>"><?php the_title(); ?></a>
                                            </h4>
                                        </div>
                                        <div class="right-wrap">
                                            <a href="<?php echo esc_url( $link ); ?>" class="a-btn-2">
												<?php esc_html_e( 'view more', 'reflector' ); ?>
                                            </a>
                                        </div>
                                    </div>
                                </div>
                            </div>

						<?php endwhile;

					} ?>

                </div>
			<?php }


			if ( $style == 'simple_categories' && ! empty( $cats ) ) { ?>

                <div class="post-list-wrapper <?php echo esc_attr( $style ); ?>">

                    <?php if(!empty($title)){ ?>
                        <div class="title">
                            <?php echo wp_kses_post($title); ?>
                        </div>
                    <?php }

                    $categories = explode( ',', $cats ); ?>


                    <div class="category-item-wrap">

	                    <?php foreach ( $categories as $category ) { ?>

                            <div class="category-item">
			                    <?php $term  = get_term( $category, 'category' );
			                    $name        = $term->name;
			                    $link        = get_term_link( $term->slug, 'category' ); ?>
                                <a href="<?php echo esc_url( $link ); ?>">
				                    <?php echo esc_html( $name ); ?>
                                </a>
                            </div>

	                    <?php } ?>
                    </div>

                    <?php if ( ! empty( $button ) ) {
	                    $url = vc_build_link( $button );
                    }

                    $btn_style = isset( $btn_style ) && ! empty( $btn_style ) ? $btn_style : 'a-btn-1';

                    if ( ! empty( $button ) && ! empty( $url['url'] ) ) { ?>
                        <div class="btn-wrapper">
		                    <?php if ( ! empty( $url['url'] ) ) {
			                    $url_targ = ! empty( $url['target'] ) ? $url['target'] : '_self'; ?>
                                <a href="<?php echo esc_url( $url['url'] ); ?>"
                                   class="<?php echo esc_attr( $btn_style ); ?>"
                                   target="<?php echo esc_attr( $url_targ ); ?>">
				                    <?php echo esc_html( $url['title'] ); ?>
                                </a>
		                    <?php } ?>
                        </div>
                    <?php } ?>

                </div>

			<?php }

			wp_reset_postdata();

			return ob_get_clean();

		}
	}
}