<?php
if ( function_exists('vc_map') ) {
	$url = EF_URL . '/admin/assets/images/shortcodes_images/post_sliders/';
	vc_map(
		array(
			'name'     => __('Post slider', 'js_composer'),
			'base'     => 'cs_post_slider',
			'category' => __('Content', 'js_composer'),
			'params'   => array(
				array(
					'type'       => 'select_preview',
					'heading'    => __('Style', 'js_composer'),
					'param_name' => 'style',
					'value'      => array(
						array(
							'value' => 'slider_simple',
							'label' => esc_html__('Simple Slider', 'js_composer'),
							'image' => $url . 'slider_simple.jpg'
						),
					),
				),
				array(
					'type'        => 'dropdown',
					'heading'     => 'Image original size',
					'description' => __('Please select image size', 'js_composer'),
					'param_name'  => 'image_original_size',
					'value'       => array_merge(array('full'), get_intermediate_image_sizes())
				),
				array(
					'type'        => 'vc_efa_chosen',
					'heading'     => __('Select Categories', 'js_composer'),
					'param_name'  => 'cats',
					'description' => __('Please select categories', 'js_composer'),
					'placeholder' => __('Select category', 'js_composer'),
					'value'       => reflector_element_values('category', array(
						'sort_order' => 'ASC',
						'taxonomy'   => 'category',
						'hide_empty' => false,
					)),
					'std'         => '',
				),
				array(
					'type'        => 'dropdown',
					'heading'     => __('Order by', 'js_composer'),
					'param_name'  => 'orderby',
					'value'       => array(
						'',
						__('Date', 'js_composer')          => 'date',
						__('ID', 'js_composer')            => 'ID',
						__('Author', 'js_composer')        => 'author',
						__('Title', 'js_composer')         => 'title',
						__('Modified', 'js_composer')      => 'modified',
						__('Random', 'js_composer')        => 'rand',
						__('Comment count', 'js_composer') => 'comment_count'
					),
					'description' => sprintf(__('Select how to sort retrieved posts. More at %s.', 'js_composer'), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>')
				),
				array(
					'type'        => 'dropdown',
					'heading'     => __('Sort order', 'js_composer'),
					'param_name'  => 'order',
					'value'       => array(
						__('Descending', 'js_composer') => 'DESC',
						__('Ascending', 'js_composer')  => 'ASC',
					),
					'description' => sprintf(__('Select ascending or descending order. More at %s.', 'js_composer'), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>')
				),
				array(
					'type'        => 'textfield',
					'heading'     => __('Count items', 'js_composer'),
					'description' => __('Please specify how many elements of the portfolio will appear on the page. Minimum 4.', 'js_composer'),
					'param_name'  => 'count',
				),
				array(
					'type'        => 'textfield',
					'heading'     => __('Autoplay speed (milliseconds)', 'js_composer'),
					'description' => __('Autoplay speed Animation. Default 5000 milliseconds', 'js_composer'),
					'param_name'  => 'autoplay',
					'value'       => '',
				),
				array(
					'type'        => 'textfield',
					'heading'     => __('Speed (milliseconds)', 'js_composer'),
					'description' => __('Speed Animation. Default 1500 milliseconds', 'js_composer'),
					'param_name'  => 'speed',
					'value'       => '',
				),
			),

			//end params
		)
	);
}

if ( class_exists('WPBakeryShortCode') ) {
	/* Frontend Output Shortcode */

	class WPBakeryShortCode_cs_post_slider extends WPBakeryShortCode {
		protected function content($atts, $content = null) {
			/* get all params */
			extract(shortcode_atts(array(
				'cats'                => '',
				'image_original_size' => 'full',
				'linked'              => 'yes',
				'style'               => 'slider_simple',
				'count'               => '',
				'autoplay'            => '5000',
				'speed'               => '1500',
				'orderby'             => '',
				'order'               => 'date'

			), $atts));


			// include needed stylesheets
			if ( !in_array("cs_post_slider-css", self::$css_scripts) ) {
				self::$css_scripts[] = "cs_post_slider-css";
			}
			$this->enqueueCss();


			// base args
			$args = array(
				'post_type'      => 'post',
				'posts_per_page' => (!empty($count) && is_numeric($count)) ? $count : 9,
				'paged'          => (get_query_var('paged')) ? get_query_var('paged') : 1
			);

			// Order posts
			if ( null !== $orderby ) {
				$args['orderby'] = $orderby;
			}
			$args['order'] = $order;

			// category
			if ( !empty($cats) ) {

				$term_array = explode(',', $cats);
				$cats       = array();

				foreach ( $term_array as $term_slug ) {
					$term_info = get_term_by('slug', $term_slug, 'category');
					$cats[]    = $term_info->term_id;
				}

				$cats              = implode(',', $cats);
				$args['tax_query'] = array(
					array(
						'taxonomy' => 'category',
						'field'    => 'term_id',
						'terms'    => explode(',', $cats),
					)
				);
			}


			$autoplay = is_numeric($autoplay) ? $autoplay : '5000';
			$speed    = is_numeric($speed) ? $speed : '1500';
			$posts = new WP_Query($args);

			ob_start(); ?>

			<?php if ( $posts->have_posts() ) { ?>
				<div class="post-slider-wrapper <?php echo esc_attr($style); ?>">
					   <?php if ( $style == 'slider_simple' ) { ?>
						<div class="swiper-container outer-pagination"
							 data-mouse="1"
							 data-autoplay="<?php echo esc_attr($autoplay); ?>"
							 data-add-slides="4"
							 data-lg-slides="4"
							 data-md-slides="3"
							 data-sm-slides="2"
							 data-xs-slides="1"
							 data-loop="1"
							 data-speed="<?php echo esc_attr($speed); ?>"
							 data-center="0"
							 data-space="80"
							 data-lg-space="30"
							 data-md-space="30"
							 data-sm-space="30"
							 data-xs-space="10"
							 data-responsive="1">
							<div class="swiper-wrapper">
								<?php while ( $posts->have_posts() ) :
									$posts->the_post();
								    $post_id = get_the_ID();
									$link    = get_the_permalink();
									$img_url = wp_get_attachment_url( get_post_thumbnail_id( $post_id ) );
									$alt = get_post_meta( get_post_thumbnail_id( $post_id ), '_wp_attachment_image_alt', true ); ?>

									<div class="swiper-slide">
										<?php if ( !empty($img_url) ) { ?>
											<div class="img-wrap">
												<?php echo reflector_the_lazy_load_flter($img_url, array(
													'class' => 's-img-switch',
                                                    'alt' => $alt
												)); ?>
											</div>
										<?php } ?>
										<div class="content-wrap">
											<div class="date"><?php echo get_the_date(); ?></div>
											<a href="<?php echo esc_url($link); ?>"
											   class="title"><?php echo esc_html(get_the_title()); ?></a>
										</div>
									</div>

								<?php endwhile; ?>
							</div>
							<div class="swiper-pagination"></div>
						</div>
					<?php } ?>
				</div>
			<?php }

			wp_reset_postdata();

			return ob_get_clean();

		}
	}
}