<?php
if ( function_exists( 'vc_map' ) ) {
	$url = EF_URL . '/admin/assets/images/shortcodes_images/space_list/';
	vc_map(
		array(
			'name'     => __( 'Space List', 'js_composer' ),
			'base'     => 'cs_space_list',
			'category' => __( 'Content', 'js_composer' ),
			'params'   => array(
				array(
					'type'        => 'select_preview',
					'param_name'  => 'style',
					'heading'     => esc_html__( 'Style', 'js_composer' ),
					'value'       => array(
						array(
							'value' => 'simple',
							'label' => esc_html__( 'Simple', 'js_composer' ),
							'image' => $url . 'simple.jpg'
						),

					),
					'admin_label' => true,
					'save_always' => true,
				),
				array(
					'type'       => 'dropdown',
					'heading'    => 'Image original size',
					'param_name' => 'image_original_size',
					'value'      => array_merge( array( 'full' ), get_intermediate_image_sizes() )
				),
				array(
					'type'        => 'vc_efa_chosen',
					'heading'     => __( 'Select Categories', 'js_composer' ),
					'param_name'  => 'cats',
					'placeholder' => __( 'Select category', 'js_composer' ),
					'value'       => reflector_element_values( 'categories', array(
						'sort_order' => 'ASC',
						'taxonomy'   => 'space-category',
						'hide_empty' => false,
					) ),
					'std'         => '',
				),
				array(
					'type'        => 'dropdown',
					'heading'     => __( 'Order by', 'js_composer' ),
					'param_name'  => 'orderby',
					'value'       => array(
						'',
						__( 'Date', 'js_composer' )          => 'date',
						__( 'ID', 'js_composer' )            => 'ID',
						__( 'Author', 'js_composer' )        => 'author',
						__( 'Title', 'js_composer' )         => 'title',
						__( 'Modified', 'js_composer' )      => 'modified',
						__( 'Random', 'js_composer' )        => 'rand',
						__( 'Comment count', 'js_composer' ) => 'comment_count'
					),
					'description' => sprintf( __( 'Select how to sort retrieved posts. More at %s.', 'js_composer' ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' )
				),
				array(
					'type'        => 'dropdown',
					'heading'     => __( 'Sort order', 'js_composer' ),
					'param_name'  => 'order',
					'value'       => array(
						__( 'Descending', 'js_composer' ) => 'DESC',
						__( 'Ascending', 'js_composer' )  => 'ASC',
					),
					'description' => sprintf( __( 'Select ascending or descending order. More at %s.', 'js_composer' ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' )
				),
				array(
					'type'       => 'textfield',
					'heading'    => __( 'Count items', 'js_composer' ),
					'param_name' => 'count',
				),
				array(
					'type'       => 'dropdown',
					'heading'    => 'Linked to detail page',
					'param_name' => 'linked',
					'value'      => array(
						'Yes'  => 'yes',
						'None' => 'none'
					)
				),
				array(
					'type'       => 'dropdown',
					'heading'    => 'Open link in a new tab?',
					'param_name' => 'blank',
					'value'      => array(
						'None' => 'none',
						'Yes'  => 'yes'
					),
				),
			)
		)
	);
}

if ( class_exists( 'WPBakeryShortCode' ) ) {
	class WPBakeryShortCode_cs_space_list extends WPBakeryShortCode {
		protected function content( $atts, $content = null ) {
			extract( shortcode_atts( array(
				'style'               => 'simple',
				'cats'                => '',
				'image_original_size' => 'full',
				'linked'              => 'yes',
				'blank'               => 'none',
				'count'               => '',
				'orderby'             => '',
				'order'               => 'date',

			), $atts ) );

			$style = isset( $style ) && ! empty( $style ) ? $style : 'simple';

			if ( ! in_array( "cs-space-list", self::$js_scripts ) ) {
				self::$js_scripts[] = "cs-space-list";
			}

			$this->enqueueJs();


			if ( ! in_array( "cs-space-list-css", self::$css_scripts ) ) {
				self::$css_scripts[] = "cs-space-list-css";
			}
			$this->enqueueCss();


			// base args
			$args = array(
				'post_type'      => 'spaces',
				'posts_per_page' => ( ! empty( $count ) && is_numeric( $count ) ) ? $count : 9,
				'paged'          => ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1
			);

			// Order posts
			if ( null !== $orderby ) {
				$args['orderby'] = $orderby;
			}
			$args['order'] = $order;

			include ABSPATH . 'wp-content/plugins/reflector-plugins/lib/aq_resizer.php';

			// category
			if ( ! empty( $cats ) ) {

				$term_array = explode( ',', $cats );
				$cats       = array();

				foreach ( $term_array as $term_slug ) {
					$term_info = get_term_by( 'slug', $term_slug, 'space-category' );
					$cats[]    = !empty( $term_info->term_id) ?  $term_info->term_id : '';
				}

				$cats              = implode( ',', $cats );
				$args['tax_query'] = array(
					array(
						'taxonomy' => 'space-category',
						'field'    => 'term_id',
						'terms'    => explode( ',', $cats ),
					)
				);
			}

			$posts = new WP_Query( $args );


			ob_start(); ?>

            <div class="space-wrap <?php echo esc_attr($style); ?>">
				<?php if ( $style == 'simple' ) {
					if ( $posts->have_posts() ) {
						while ( $posts->have_posts() ) :
							$posts->the_post();

							$space_meta = get_post_meta( get_the_ID(), 'reflector_space_options', true );

							$link = get_the_permalink();

							if ( $linked == 'none' && isset( $space_meta['ext_link'] ) && ! empty( $space_meta['ext_link'] ) ) {
								$link = $space_meta['ext_link'];
							}

							if ( $blank == 'none' ) {
								$target = '_self';
							} elseif ( $blank == 'yes' ) {
								$target = '_blank';
							}

							if ( get_post_thumbnail_id( $posts->ID ) ) {
								$image_id  = get_post_thumbnail_id( $posts->ID );
								$image     = ( is_numeric( $image_id ) && ! empty( $image_id ) ) ? wp_get_attachment_image_url( $image_id, $image_original_size ) : '';
								$image_alt = get_post_meta( $image_id, '_wp_attachment_image_alt', true );
							} ?>

                            <div class="item">
								<?php if ( ! empty( $image ) ) { ?>
                                    <div class="image-container">
                                        <a href="<?php echo esc_url( $link ); ?>" class="image-wrap"
                                           target="<?php echo esc_attr( $target ); ?>">
                                            <img src="<?php echo esc_url( $image ); ?>"
                                                 alt="<?php echo esc_attr( $image_alt ); ?>" class="s-img-switch">
                                        </a>
                                    </div>
								<?php } ?>
                                <a href="<?php echo esc_url( $link ); ?>" target="<?php echo esc_attr( $target ); ?>"
                                   class="title"><?php the_title(); ?></a>
                            </div>
						<?php

						endwhile;
					}
				} ?>
            </div>


			<?php wp_reset_postdata();

			return ob_get_clean();
		}
	}
}