<?php
if ( function_exists('vc_map') ) {
	$url     = EF_URL . '/admin/assets/images/shortcodes_images/testimonials/';
	vc_map(
		array(
			'name'        => __('Testimonial', 'js_composer'),
			'base'        => 'cs_testimonial',
			'description' => __('Image with name, position and description', 'js_composer'),
			'category'    => __('Content', 'js_composer'),
			'params'      => array(
				array(
					'type'        => 'select_preview',
					'param_name'  => 'style',
					'heading'     => esc_html__('Style', 'js_composer'),
					'value'       => array(
						array(
							'value' => 'urban',
							'label' => esc_html__('Urban slider', 'js_composer'),
							'image' => $url . 'urban.jpg'
						),
						array(
							'value' => 'dark_urban',
							'label' => esc_html__('Dark Urban slider', 'js_composer'),
							'image' => $url . 'dark_urban.jpg'
						),
						array(
							'value' => 'gold_urban',
							'label' => esc_html__('Gold Urban slider', 'js_composer'),
							'image' => $url . 'gold_urban.jpg'
						),
					),
					'admin_label' => true,
					'save_always' => true,
				),
				array(
					'type'        => 'textfield',
					'heading'     => __('Autoplay (sec)', 'js_composer'),
					'description' => __('0 - off autoplay.', 'js_composer'),
					'param_name'  => 'autoplay',
					'value'       => '0'
				),
				array(
					'type'        => 'textfield',
					'heading'     => __('Speed (milliseconds)', 'js_composer'),
					'description' => __('Speed Animation. Default 500 milliseconds', 'js_composer'),
					'param_name'  => 'speed',
					'value'       => '500'
				),
				array(
					'type'        => 'textfield',
					'description' => __('Please add text your subtitle', 'js_composer'),
					'heading'     => __('Subtitle', 'js_composer'),
					'param_name'  => 'subtitle',
					'dependency'  => array('element' => 'style', 'value' => array('urban'))
				),
				array(
					'type'        => 'param_group',
					'heading'     => __('Items', 'js_composer'),
					'description' => __('Please add options for Testimonial item', 'js_composer'),
					'param_name'  => 'items_urban',
					'value'       => '',
					'params'      => array(
						array(
							'type'       => 'textfield',
							'heading'    => __("Author's name", 'js_composer'),
							'param_name' => 'author',
							'value'      => ''
						),
						array(
							'type'        => 'textarea',
							'heading'     => __('Text', 'js_composer'),
							'param_name'  => 'text',
							'value'       => '',
							'description' => __('Max - 153 symbols.', 'js_composer')
						),
					),
					'dependency'  => array('element' => 'style', 'value' => array('urban', 'dark_urban', 'gold_urban'))
				),
			) //end params
		)
	);
}

if ( class_exists('WPBakeryShortCode') ) {
	class WPBakeryShortCode_cs_testimonial extends WPBakeryShortCode {
		protected function content($atts, $content = null) {

			extract(shortcode_atts(array(
				'style'            => '',
				'autoplay'         => '',
				'subtitle'         => '',
				'light'            => '',
				'items_urban'      => '',
				'speed'            => ''
			), $atts));

			if ( !in_array("cs_testimonial", self::$js_scripts) ) {
				self::$js_scripts[] = "cs_testimonial";
			}
			$this->enqueueJs();

			// include needed stylesheets
			if ( !in_array("cs_testimonial-css", self::$css_scripts) ) {
				self::$css_scripts[] = "cs_testimonial-css";
			}
			$this->enqueueCss();

			$style = isset($style) && !empty($style) ? $style : 'vertical';
			$autoplay = !empty($autoplay) && is_numeric($autoplay) ? $autoplay * 1000 : 0;
			$speed    = !empty($speed) && is_numeric($speed) ? $speed : '500';

			ob_start(); ?>

			<div class="main-header-testimonial <?php echo esc_attr($style ); ?>">
				   <?php if ( ($style == 'urban' || $style == 'dark_urban' || $style == 'gold_urban') && !empty($items_urban) ) {
					$items_urban = (array)vc_param_group_parse_atts($items_urban); ?>
					<div class="container">
						<div class="row">
							<div class="col-12">
								<?php if ( !empty($subtitle) && $style != 'dark_urban' && $style != 'gold_urban') { ?>
									<div class="subtitle"><?php echo esc_html($subtitle); ?></div>
								<?php } ?>
								<div class="swiper-container"
									 data-autoplay="<?php echo esc_attr($autoplay); ?>"
									 data-loop="1" data-speed="<?php echo esc_attr($speed); ?>"
									 data-space="0" data-mode="horizontal">
									<div class="swiper-wrapper">
										<?php foreach ( $items_urban as $item ) { ?>
											<div class="swiper-slide">
												<div class="content-slide">
													<div class="user-info">
														<?php if ( !empty($item['text']) ) { ?>
															<div class="description">
                                                                <?php if( $style == 'urban'){ ?>
                                                                    <div class="img-wrap">
                                                                        <img src="<?php echo EF_URL . '/shortcodes/assets/images/quote-s.png'; ?>"
                                                                             alt="">
                                                                    </div>
                                                                <?php } ?>
																<p><?php echo do_shortcode($item['text']); ?></p>
															</div>
														<?php }
														if ( !empty($item['author']) ) { ?>
															<?php if ( !empty($item['author']) ) { ?>
																<div class="name"><?php echo esc_html($item['author']); ?></div>
															<?php } ?>
														<?php } ?>
													</div>
												</div>
											</div>
										<?php } ?>
									</div>
								</div>
                                <div class="swiper-btn-wrap">
                                    <div class="swiper-button-prev swiper-button"><?php echo esc_html__('Prev.', 'reflector'); ?></div>
                                    <div class="swiper-button-next swiper-button"><?php echo esc_html__('Next.', 'reflector'); ?></div>
                                </div>
							</div>
						</div>
					</div>
				<?php } ?>
			</div>
			<?php

			return ob_get_clean();
		}
	}
}